@@ -103,11 +103,6 @@
 /* hardware rendering is an option? */
 #define DXD_CAN_HAVE_HW_RENDERING 1
 
-#if defined(HAVE_LIBGL) || defined(HAVE_LIBGLWSTATI)
-/* is hardware sensitive to vertex orientation of 1st triangle in strip? */
-#define DXD_HW_TMESH_ORIENT_SENSITIVE 1
-#endif
-
 /* supports full IEEE standard floating point, including under/overflow */
 #define DXD_STANDARD_IEEE 1
 
@@ -392,6 +387,9 @@ char *strrstr(char *, char *);
 /* can you use rlimit to stop the exec from creating a huge core file? */
 #define DXD_HAS_RLIMIT 1
 
+/* is hardware sensitive to vertex orientation of 1st triangle in strip? */
+#define DXD_HW_TMESH_ORIENT_SENSITIVE 1
+
 /* Does the X server behave correctly for a move of a XGL window */
 #define DXD_HW_XSERVER_MOVE_OK 1
 
@@ -447,6 +445,9 @@ char *strrstr(char *, char *);
 /* can you use rlimit to stop the exec from creating a huge core file? */
 #define DXD_HAS_RLIMIT 1
 
+/* is hardware sensitive to vertex orientation of 1st triangle in strip? */
+#define DXD_HW_TMESH_ORIENT_SENSITIVE 1
+
 /* can use the crypt system call for data encryption */
 #define DXD_HAS_CRYPT  1
 
@@ -536,6 +537,16 @@ union wait{
 
 #if defined(intelnt) || defined(WIN32)
 
+#ifdef snprintf
+#undef snprintf
+#endif
+#define snprintf _snprintf
+
+#ifdef vsnprintf
+#undef vsnprintf
+#endif
+#define vsnprintf _vsnprintf
+
 #if defined(alloca)
 #undef alloca
 #endif
@@ -715,7 +726,7 @@ int getopt(int,char**,char*);
 #define DXD_MAX_INT      2147483647
 #define DXD_MIN_INT     -2147483648
 
-#define DXD_MAX_UINT     4294967295
+#define DXD_MAX_UINT     4294967295U
 
 /* same whether denormalized numbers are supported nor not */
 #define DXD_MAX_FLOAT       ((float)3.40282346638528860e+38)
