@@ -19,8 +19,10 @@
 #endif
 
 #include <stdio.h>
-#include <ctype.h>
 
+#if defined(HAVE_CTYPE_H)
+#include <ctype.h>
+#endif
 #if defined(HAVE_SYS_TYPES_H)
 #include <sys/types.h>
 #endif
@@ -48,6 +50,12 @@
 #if defined(HAVE_SYS_UTSNAME_H)
 #include <sys/utsname.h>
 #endif
+#if defined(HAVE_SYS_STAT_H)
+#include <sys/stat.h>
+#endif
+#if defined(HAVE_STRING_H)
+#include <string.h>
+#endif
 
 #include "ccm.h"
 
@@ -78,7 +86,7 @@ _dxfSetupServer(int pport, int *psock,
     int oldUmask;
 #endif
     struct linger sl;
-    int length;
+    socklen_t length;
     u_short port;
     int sts;
     int oldPort;
@@ -221,8 +229,8 @@ _dxfCompleteServer(int sock,
     , int timeout
     )
 {
-    int length;
-    int fd;
+    socklen_t length;
+    int fd=-1;
     int sts;
     extern int errno; /* from <errno.h> */
     fd_set fds;
@@ -265,7 +273,8 @@ _dxfCompleteServer(int sock,
     if (FD_ISSET(sock, &fds))
     {
 	length = sizeof(server);
-	if (accept(sock, (struct sockaddr *)&server, &length) < 0)
+        fd = accept(sock, (struct sockaddr *)&server, &length);
+	if (fd < 0)
 	{
 	    perror ("accept");
 	    goto error;
@@ -275,7 +284,8 @@ _dxfCompleteServer(int sock,
     else
     {
 	length = sizeof (userver) - sizeof(userver.sun_path) + strlen (userver.sun_path);
-	if (accept(usock, (struct sockaddr *)&userver, &length) < 0)
+        fd = accept(usock, (struct sockaddr *)&userver, &length);
+	if (fd < 0)
 	{
 	    perror ("accept");
 	    goto error;
