@@ -5,5 +5,5 @@
 /* This code licensed under the                                        */
 /*    "IBM PUBLIC LICENSE - Open Visualization Data Explorer"          */
 /***********************************************************************/
-#define EX_COM_DATE "Mon Jan 9 16:39:11 MST 2006"
-#define EX_COM_HOST "Darwin beaverhead 8.3.0 Darwin Kernel Version 8.3.0: Mon Oct 3 20:04:04 PDT 2005; root:xnu-792.6.22.obj~2/RELEASE_PPC Power Macintosh powerpc"
+#define EX_COM_DATE "Fri Aug 4 15:41:42 MDT 2006"
+#define EX_COM_HOST "Darwin beaverhead 8.7.0 Darwin Kernel Version 8.7.0: Fri May 26 15:20:53 PDT 2006; root:xnu-792.6.76.obj~1/RELEASE_PPC Power Macintosh powerpc"
