@@ -6,7 +6,7 @@
 /*    "IBM PUBLIC LICENSE - Open Visualization Data Explorer"          */
 /***********************************************************************/
 /*
- * $Header: /src/master/dx/src/exec/dpexec/context.h,v 1.5 2000/08/11 15:28:10 davidt Exp $
+ * $Header: /src/master/dx/src/exec/dpexec/context.h,v 1.6 2004/06/09 16:14:27 davidt Exp $
  */
 
 #include <dxconfig.h>
@@ -16,6 +16,10 @@
 
 #include "graph.h"
 
+#if defined(__cplusplus) || defined(c_plusplus)
+extern "C" {
+#endif
+
 typedef struct Context
 {
     int userId;
@@ -26,4 +30,8 @@ typedef struct Context
 
 void _dxfCopyContext(Context *to, Context *from);
 
+#if defined(__cplusplus) || defined(c_plusplus)
+}
+#endif
+
 #endif /* _CONTEXT_H */
