@@ -13,3 +13,9 @@
 int GetMPINodeId() { return 0; }
 int SlaveBcastLoop() { return 0; }
 #endif
+void GetBaseConnection(FILE **fptr, char **str)
+{
+    setvbuf (stdin, NULL, _IONBF, 0);
+    *fptr = stdin;
+    *str  = "STDIN";
+}
