@@ -6,7 +6,7 @@
 /*    "IBM PUBLIC LICENSE - Open Visualization Data Explorer"          */
 /***********************************************************************/
 /*
- * $Header: /src/master/dx/src/exec/dpexec/dxmain.h,v 1.1 2000/10/04 17:45:58 davidt Exp $
+ * $Header: /src/master/dx/src/exec/dpexec/dxmain.h,v 1.2 2004/06/09 16:14:27 davidt Exp $
  */
 
 #ifndef	_DXMAIN_H_
@@ -14,6 +14,10 @@
 
 #include <dx/dx.h>
 
+#if defined(__cplusplus) || defined(c_plusplus)
+extern "C" {
+#endif
+
 /* Function prototypes */
 
 char ** _dxf_ExEnvp (void);
@@ -26,4 +30,8 @@ void _dxf_set_RQ_ReadFromChild1(int);
 void _dxf_set_RQ_reader(int);
 void _dxf_set_RQ_writer(int);
 
+#if defined(__cplusplus) || defined(c_plusplus)
+}
+#endif
+
 #endif /* _DXMAIN_H_ */
