@@ -6,7 +6,7 @@
 /*    "IBM PUBLIC LICENSE - Open Visualization Data Explorer"          */
 /***********************************************************************/
 /*
- * $Header: /src/master/dx/src/exec/dpexec/evalgraph.h,v 1.2 2000/08/11 15:28:11 davidt Exp $
+ * $Header: /src/master/dx/src/exec/dpexec/evalgraph.h,v 1.3 2004/06/09 16:14:27 davidt Exp $
  */
 
 #ifndef _EVALGRAPH_H
@@ -14,6 +14,10 @@
 
 #include "graph.h"
 
+#if defined(__cplusplus) || defined(c_plusplus)
+extern "C" {
+#endif
+
 typedef struct qsr_args {
     char *procid;
     ProgramVariable *pv;
@@ -28,4 +32,8 @@ void        _dxf_ExQueueGraph(Program * p);
 void        DXLoopDone(int done);
 int 	    _dxf_ExIsExecuting();
 
+#if defined(__cplusplus) || defined(c_plusplus)
+}
+#endif
+
 #endif /* _EVALGRAPH_H */
