@@ -118,12 +118,12 @@ Error m__badfunc(Object *in, Object *out)
     return ERROR;
 }
 
-static PFI gvar_methods[] =
+static PFIP gvar_methods[] =
 {
     GvarDelete
 };
 
-static PFI progobj_methods[] =
+static PFIP progobj_methods[] =
 {
     progobjDelete
 };
@@ -1351,6 +1351,7 @@ ExGraphCall (Program *p, node *n, int top, list_int *out, EXDictionary dict, int
 		if (ind == NULL)
 		{
 		    pr.name = _dxf_ExCopyString/*Local*/ (val->v.id.id);
+            pr.oneshot = NULL;
 		    inArgs[slot] = pr.index = SIZE_LIST (p->vars);
                     ExDebug("1","pr.name %s, pr.index %d\n", pr.name, pr.index);
 		    APPEND_LIST (ProgramRef, p->undefineds, pr);
@@ -1966,6 +1967,7 @@ static Program *GetNewMacro(Program *p, int *map, int *resolved)
         }
         else pr.index = slot;
         pr.name = _dxf_ExCopyString(pPr->name);
+        pr.oneshot = NULL;
         ExDebug("1","pr.name %s, pr.index %d\n", pr.name, pr.index);
         APPEND_LIST (ProgramRef, newp->undefineds, pr);
     }
@@ -2004,6 +2006,7 @@ static void ExCopySubP(Program *toP, Program *fromP, int top)
         pPr = FETCH_LIST(fromP->undefineds, i);
         pr.index = pPr->index;
         pr.name = _dxf_ExCopyString(pPr->name);
+        pr.oneshot = NULL;
         ExDebug("1","pr.name %s, pr.index %d\n", pr.name, pr.index);
         APPEND_LIST (ProgramRef, toP->undefineds, pr);
     }
@@ -2983,7 +2986,7 @@ static void _dxf_ExPathPrepend( Program *p, char fname[], int instance,
   {
     DXSetError(ERROR_NOT_IMPLEMENTED, "gfunc execution path too deep");
     printf( "gfunc execution path too deep: %d", path->num_comp );
-    exit(1);
+    _dxf_ExDie("gfunc execution path too deep");
     return;
   }
 
@@ -3010,7 +3013,7 @@ static void _dxf_ExPathAppend( Program *p, char fname[], int instance,
   {
     DXSetError(ERROR_NOT_IMPLEMENTED, "gfunc execution path too deep");
     printf( "gfunc execution path too deep: %d", path->num_comp );
-    exit(1);
+    _dxf_ExDie("gfunc execution path too deep");
     return;
   }
 
