@@ -6,7 +6,7 @@
 /*    "IBM PUBLIC LICENSE - Open Visualization Data Explorer"          */
 /***********************************************************************/
 /*
- * $Header: /src/master/dx/src/exec/dpexec/lex.h,v 1.2 2000/08/11 15:28:12 davidt Exp $
+ * $Header: /src/master/dx/src/exec/dpexec/lex.h,v 1.3 2004/06/09 16:14:28 davidt Exp $
  */
 
 #ifndef _LEX_H
@@ -15,6 +15,10 @@
 #include "parse.h"
 #include "sfile.h"
 
+#if defined(__cplusplus) || defined(c_plusplus)
+extern "C" {
+#endif
+
 #define LINEFEED 10
 
 #define YYLMAX_1        4000            /* max string/identifer length */
@@ -38,4 +42,8 @@ int   ExCheckParseBuffer();
 int   yylex();
 void  yygrabdata(char *buffer, int len);
 
+#if defined(__cplusplus) || defined(c_plusplus)
+}
+#endif
+
 #endif /* _LEX_H */
