@@ -6,7 +6,7 @@
 /*    "IBM PUBLIC LICENSE - Open Visualization Data Explorer"          */
 /***********************************************************************/
 /*
- * $Header: /src/master/dx/src/exec/dpexec/log.h,v 1.5 2000/08/11 15:28:12 davidt Exp $
+ * $Header: /src/master/dx/src/exec/dpexec/log.h,v 1.7 2004/06/09 16:14:28 davidt Exp $
  */
 
 #include <dxconfig.h>
@@ -14,6 +14,10 @@
 #ifndef _LOG_H
 #define _LOG_H
 
+#if defined(__cplusplus) || defined(c_plusplus)
+extern "C" {
+#endif
+
 #define LOG_FATAL	0
 #define LOG_ERROR	1
 #define LOG_WARNING	2
@@ -24,12 +28,14 @@
 #define LOG_APPEND	0x8000
 #define LOG_MASK	0x7fff
 
-extern int _dxd_exErrorPrintLevel;
-
 int _dxf_ExLogOpen();
 void _dxf_ExLogClose();
 int lprintf(int type, char *format, ...);
 void _dxf_ExQMessage(int type, int graphId, int len, char *buf);
 void _dxf_ExLogError (int errnum);
 
+#if defined(__cplusplus) || defined(c_plusplus)
+}
+#endif
+
 #endif /* _LOG_H */
