@@ -6,9 +6,13 @@
 /*    "IBM PUBLIC LICENSE - Open Visualization Data Explorer"          */
 /***********************************************************************/
 /*
- * $Header: /src/master/dx/src/exec/dpexec/pendingcmds.h,v 1.2 2000/08/11 15:28:13 davidt Exp $
+ * $Header: /src/master/dx/src/exec/dpexec/pendingcmds.h,v 1.4 2006/01/04 22:00:49 davidt Exp $
  */
 
+#if defined(__cplusplus) || defined(c_plusplus)
+extern "C" {
+#endif
+
 #ifndef _PENDINGCMDS_H
 #define _PENDINGCMDS_H
 
@@ -25,7 +29,7 @@ typedef struct
 
 typedef struct
 {
-    Object       private;
+    Object       exprivate;
     PendingCmd  *pendingCmdList;
     int          pendingCmdListMax;
     int          pendingCmdListSize;
@@ -35,3 +39,7 @@ Error _dxf_RunPendingCmds();
 Error _dxf_CleanupPendingCmdList();
 
 #endif /* _PENDINGCMDS_H */
+
+#if defined(__cplusplus) || defined(c_plusplus)
+}
+#endif
