@@ -102,21 +102,31 @@ extern int _dxfHostIsLocal(char *host); /* from libdx/ */
 
 Error ExHostToFQDN( const char host[], char fqdn[MAXHOSTNAMELEN] )
 {
+    long addr;
     struct hostent *hp, *hp2;
 
     hp = gethostbyname(host);
     if ( hp == NULL || hp->h_addr_list[0] == NULL ) {
-       DXUIMessage("ERROR", "gethostbyname returned error");
-       return ERROR;
-    }
-    hp2 = gethostbyaddr( hp->h_addr_list[0], sizeof(struct in_addr),
+       DXUIMessage("WARNING", "gethostbyname returned error");
+       DXUIMessage("WARNING", "it appears %s doesn't have a host entry?", host);
+       DXUIMessage("WARNING", "trying localhost.");
+       addr = 0x7f000001; /* 127.0.0.1 */
+    } else 
+    	addr = *(long *)hp->h_addr_list[0];
+
+    hp2 = gethostbyaddr((const char *)&addr, sizeof(struct in_addr),
                         AF_INET );
     if ( hp2 == NULL || hp2->h_name == NULL ) {
-       DXUIMessage("ERROR", "gethostbyaddr returned error");
-       return ERROR;
+        if(_dxfHostIsLocal((char *)host)) {
+            strncpy( fqdn, "localhost", MAXHOSTNAMELEN );
+            DXMessage("Warning: Cannot get FQDN; no DNS entry. Assuming localhost.");
+            return OK;
+        }
+        DXUIMessage("ERROR", "gethostbyaddr returned error");
+        DXSetError(ERROR_UNEXPECTED, "gethostbyaddr error--is it possible this machine doesn't have a DNS/host entry?");
+        return ERROR;
     }
-    fqdn[0] = '\0';
-    strncat( fqdn, hp2->h_name, MAXHOSTNAMELEN );
+    strncpy( fqdn, hp2->h_name, MAXHOSTNAMELEN );
     return OK;
 }
 
@@ -136,10 +146,8 @@ ExConnectTo(char *host, char *user, char *cwd, int ac, char *av[], char *ep[],
     char localhost[MAXHOSTNAMELEN];
     FILE *fp = NULL;
     int i, k;
-    int in[2], out[2], err[2];
     char **rep;
     char *fargv[MAX_STARTUP_ARGS];
-    int child;
     struct hostent *he;
     int findx;
     char *pathEnv;
@@ -148,6 +156,11 @@ ExConnectTo(char *host, char *user, char *cwd, int ac, char *av[], char *ep[],
     int found;
     int rsh_noenv;
     char *local_rsh_cmd;
+#if ! defined(DXD_HAS_LIBIOP)
+    int in[2], out[2], err[2];
+    int child;
+#endif
+
 
 #if HAVE_GETDTABLESIZE
     int  width = getdtablesize();
@@ -550,12 +563,14 @@ int _dxfExRemoteExec(int dconnect, char *host, char *ruser, int r_argc,
     int                 nargc;
 
  
+    printf("In _dxfExRemoteExec. Host is %s\n", host);
     if (gethostname (myhost, sizeof(myhost)) < 0)
         goto error;
-    if ( ExHostToFQDN( myhost, myhost ) == ERROR)
-	goto error;
 
-    if ((unsigned int)(getcwd (cwd, sizeof (cwd))) == (unsigned int)NULL)
+    if ( ExHostToFQDN( myhost, myhost ) == ERROR)
+        goto error;
+
+    if (getcwd (cwd, sizeof (cwd)) == NULL)
 	goto error;
     if (spath == NULL)
     {
@@ -945,7 +960,7 @@ _dxfExRemote (Object *in, Object *out)
             FD_SET(fd, &fdset);
             tv.tv_sec = 0;
             tv.tv_usec = 0;
-            nsel = select(fd + 1, (SelectPtr) &fdset, NULL, NULL, &tv);
+            nsel = select(fd + 1, (SELECT_ARG_TYPE *) &fdset, NULL, NULL, &tv);
             if(nsel > 0) {
                 if((IOCTL(fd, FIONREAD, (char *)&b) < 0) || b <= 0)  {
                     DXSetError(ERROR_DATA_INVALID, 
@@ -975,7 +990,7 @@ _dxfExRemote (Object *in, Object *out)
 		msgObj = DXGetEnumeratedMember((Group)obj, 1, NULL);
 		if (!msgObj || !DXExtractString(msgObj, &msg))
 		    goto message_cleanup;
-		
+
 		DXqmessage (who, msg, nolist);
 	    }
 	    /* async request */
