@@ -6,7 +6,7 @@
 /*    "IBM PUBLIC LICENSE - Open Visualization Data Explorer"          */
 /***********************************************************************/
 /*
- * $Header: /src/master/dx/src/exec/dpexec/rih.h,v 1.2 2000/08/11 15:28:13 davidt Exp $
+ * $Header: /src/master/dx/src/exec/dpexec/rih.h,v 1.3 2004/06/09 16:14:28 davidt Exp $
  */
 
 #ifndef _RIH_H
@@ -16,6 +16,10 @@
 #include <dx/dx.h>
 #include "utils.h"
 
+#if defined(__cplusplus) || defined(c_plusplus)
+extern "C" {
+#endif
+
 typedef struct
 {
     PFE         proc;
@@ -37,4 +41,8 @@ typedef struct
 int   _dxf_ExCheckRIH (void);
 int _dxf_ExCheckRIHBlock (int input);
 
+#if defined(__cplusplus) || defined(c_plusplus)
+}
+#endif
+
 #endif /* _RIH_H */
