@@ -34,6 +34,16 @@
 #include <sys/select.h>
 #endif
 
+#if defined(HAVE_SYS_IOCTL_H)
+#include <sys/ioctl.h>
+#endif
+
+#if defined(HAVE_STRING_H)
+#include <string.h>
+#endif
+
+#include <errno.h>
+
 struct sfile
 {
     enum 
@@ -209,11 +219,17 @@ writeToSFILE(SFILE *sf, char *buf, int n)
 	}
     else
 #endif
-        rtn = write(ssf->fd, buf, n);
+/*	errno = 0; */
+	rtn = write(ssf->fd, buf, n);
 
-    if (rtn < 0)
+    if (rtn < 0) {
+
+#if defined(_DEBUG) && defined(intelnt)
+		int err = WSAGetLastError();
 		ExQuit();
-    
+#endif
+/*	fprintf(stderr, "Errorno is: %d\n", errno); */
+    }
     return rtn;
 }
 
@@ -381,7 +397,7 @@ SFILEIoctl(SFILE *sf, int cmd, void *argp)
 	return ioctlsocket(ssf->socket, cmd, argp);
     else
 #endif
-#if defined(HAVE_IOCTL)
+#if defined(HAVE_SYS_IOCTL_H)
     return ioctl(ssf->fd, cmd, argp);
 #else
     return 1;
