@@ -6,24 +6,27 @@
 /*    "IBM PUBLIC LICENSE - Open Visualization Data Explorer"          */
 /***********************************************************************/
 /*
- * $Header: /src/master/dx/src/exec/dpexec/sfile.h,v 1.5 2002/03/26 21:25:24 gda Exp $
+ * $Header: /src/master/dx/src/exec/dpexec/sfile.h,v 1.7 2004/06/09 16:14:28 davidt Exp $
  */
 
 #ifndef _SFILE_H
 #define _SFILE_H
 
+#if defined(__cplusplus) || defined(c_plusplus)
+extern "C" {
+#endif
+
 typedef void SFILE;
 
 #if !defined(HAVE_CYGWIN_SOCKET_H) &&  !defined(HAVE_SYS_SOCKET_H) && !defined(HAVE_SOCKET_H) && defined(HAVE_WINSOCK_H)
-#define HANDLE_SOCKET
-SFILE *socketToSFILE(SOCKET sock);
-#endif
-
-#if !defined(SOCKET)
-#define SOCKET int
-#endif
-
+#  define HANDLE_SOCKET
+   SFILE *socketToSFILE(SOCKET sock);
+#else
+#  if !defined(SOCKET)
+#    define SOCKET int
+#  endif
 SFILE *socketToSFILE(SOCKET);
+#endif
 
 SFILE *fdToSFILE(int fd);
 SFILE *FILEToSFILE(FILE *fptr);
@@ -36,4 +39,8 @@ int    SFILEIoctl(SFILE *sf, int cmd, void *argp);
 int    SFILEfileno(SFILE *sf);
 int    SFILEisatty(SFILE *sf);
 
+#if defined(__cplusplus) || defined(c_plusplus)
+}
+#endif
+
 #endif /* _SFILE_H */
