@@ -107,7 +107,13 @@ int _dxf_ExGetSocket(char *name, int *port)
 SFILE *
 _dxf_ExInitServer(int pport)
 {
-    int sock = -1;
+
+#if defined(HANDLE_SOCKET)
+	SOCKET sock = INVALID_SOCKET;
+#else
+	SOCKET sock = -1;
+#endif
+
     struct sockaddr_in server;
 #if DXD_SOCKET_UNIXDOMAIN_OK
     int usock = -1;
@@ -133,7 +139,11 @@ retry:
 
 
     sock = socket(AF_INET, SOCK_STREAM, 0);
-    if (sock < 0)
+#if defined(HANDLE_SOCKET)
+	if (sock < 0 || sock == INVALID_SOCKET)
+#else
+	if(sock < 0)
+#endif
     {
 	perror ("socket");
 	fd = -1;
@@ -380,7 +390,12 @@ error:
 	close (usock);
 #endif
     if (sock >= 0)
-	close (sock);
+
+#if defined(HANDLE_SOCKET)
+		closesocket(sock);
+#else
+		close (sock);
+#endif
     return socketToSFILE((SOCKET)fd);
 }
 
