@@ -6,12 +6,20 @@
 /*    "IBM PUBLIC LICENSE - Open Visualization Data Explorer"          */
 /***********************************************************************/
 /*
- * $Header: /src/master/dx/src/exec/dpexec/socket.h,v 1.2 2000/08/11 15:28:14 davidt Exp $
+ * $Header: /src/master/dx/src/exec/dpexec/socket.h,v 1.3 2004/06/09 16:14:28 davidt Exp $
  */
 
 #ifndef _SOCKET_H
 #define _SOCKET_H
 
+#if defined(__cplusplus) || defined(c_plusplus)
+extern "C" {
+#endif
+
 int   _dxf_ExGetSocket(char *name, int *port);
 
+#if defined(__cplusplus) || defined(c_plusplus)
+}
+#endif
+
 #endif /* _SOCKET_H */
