@@ -6,7 +6,7 @@
 /*    "IBM PUBLIC LICENSE - Open Visualization Data Explorer"          */
 /***********************************************************************/
 /*
- * $Header: /src/master/dx/src/exec/dpexec/task.h,v 1.4 2002/03/21 21:14:42 rhh Exp $
+ * $Header: /src/master/dx/src/exec/dpexec/task.h,v 1.7 2006/01/04 22:00:49 davidt Exp $
  */
 
 #ifndef _TASK_H
@@ -15,6 +15,10 @@
 #include "utils.h"
 #include "context.h"
 
+#if defined(__cplusplus) || defined(c_plusplus)
+extern "C" {
+#endif
+
 typedef struct _EXTask          *EXTask;
 typedef struct _EXTaskGroup     *EXTaskGroup;
 
@@ -32,7 +36,7 @@ typedef struct _EXTask
     PFE                 func;                   /* function to call     */
     int                 repeat;                 /* number of requested reps */
     int                 nocopy;                 /* just pass arg flag   */
-    int                 delete;                 /* 1->not in `tasks' array */
+    int                 exdelete;                 /* 1->not in `tasks' array */
     Pointer             arg;                    /* function argument    */
     unsigned char       data[EX_TASK_DATA];     /* local data storage   */
     Context             taskContext;            /* copy of global context */
@@ -69,3 +73,6 @@ Error 		_dxf_ExInitTask(int n);
 
 
 #endif /* _TASK_H */
+#if defined(__cplusplus) || defined(c_plusplus)
+}
+#endif
