@@ -6,7 +6,7 @@
 /*    "IBM PUBLIC LICENSE - Open Visualization Data Explorer"          */
 /***********************************************************************/
 /*
- * $Header: /src/master/dx/src/exec/dpexec/utils.h,v 1.7 2002/03/21 21:14:42 rhh Exp $
+ * $Header: /src/master/dx/src/exec/dpexec/utils.h,v 1.9 2004/06/09 16:14:29 davidt Exp $
  */
 
 #include <dxconfig.h>
@@ -19,6 +19,10 @@
 #include <dx/dx.h>
 #include <dx/arch.h>
 
+#if defined(__cplusplus) || defined(c_plusplus)
+extern "C" {
+#endif
+
 #ifndef NULL
 #define	NULL		0
 #endif
@@ -49,6 +53,7 @@ char *_dxf_ExStrSave (char *old);
 typedef char			(*PFC)();
 typedef short			(*PFS)();
 typedef int			(*PFI)();
+typedef int			(*PFIP)(void *);
 typedef long			(*PFL)();
 typedef float			(*PFF)();
 typedef double			(*PFD)();
@@ -158,4 +163,8 @@ Array 		_dxfExNewInteger 		(int n);
 #define	ExMarkTime(_m,_t)	if (_m & _dxd_exMarkMask) DXMarkTime (_t)
 #define	ExMarkTimeLocal(_m,_t)	if (_m & _dxd_exMarkMask) DXMarkTimeLocal (_t)
 
+#if defined(__cplusplus) || defined(c_plusplus)
+}
+#endif
+
 #endif	/* __EX_UTILS_H */
