@@ -70,6 +70,10 @@
  *		if the binding shape == 1, it allows any dimension and shape.
  */
 
+#if defined(HAVE_STRINGS_H)
+#include <strings.h>
+#endif
+
 #include <stdio.h>
 #include <math.h>
 #include <dx/dx.h>
