@@ -6,11 +6,14 @@
 /*    "IBM PUBLIC LICENSE - Open Visualization Data Explorer"          */
 /***********************************************************************/
 /*
- * $Header: /src/master/dx/src/exec/dxmods/_maptoplane.c,v 1.6 2002/03/21 02:57:29 rhh Exp $
+ * $Header: /src/master/dx/src/exec/dxmods/_maptoplane.c,v 1.7 2006/01/03 17:02:21 davidt Exp $
  */
 
 #include <dxconfig.h>
 
+#if defined(HAVE_STRING_H)
+#include <string.h>
+#endif
 
 #include <stdio.h>
 #include <math.h>
