@@ -8,6 +8,9 @@
 
 #include <dxconfig.h>
 
+#if defined(HAVE_STRING_H)
+#include <string.h>
+#endif
 
 #define	TRIANGULATE_ALWAYS		1
 #define	TRIANGULATE_DEBUG		1
@@ -405,7 +408,7 @@ _dxf__TriangulateFLEP (FLEP *in, Vector *normal, Triangle *tris, int *ntri,
     int         temp, k;
     float       dir;
     FLEP	lin;
-    FLEP	lvalid;
+    FLEP	lvalid= {NULL, NULL};
     Error	ret	= ERROR;
     Loop	*loops	= NULL;
     int		size;
@@ -455,9 +458,9 @@ _dxf__TriangulateFLEP (FLEP *in, Vector *normal, Triangle *tris, int *ntri,
 	    loops[l - ls - skips].vids  = lin.edges + es;
 	}
 
-	if (getenv("DX_NESTED_LOOPS"))
+	if (getenv("DX_SIMPLE_LOOPS"))
 	{
-	    if (! TriangulateNestedLoops (le - ls - skips, loops, lin.points,
+	    if (! TriangulateLoops (le - ls - skips, loops, lin.points,
 		    (normal) ? normal + f : NULL, lin.npoints, ltris, &ftri, lin.nDim))
 	    {
 #if TRIANGULATE_ALWAYS
@@ -470,7 +473,7 @@ _dxf__TriangulateFLEP (FLEP *in, Vector *normal, Triangle *tris, int *ntri,
 	}
 	else
 	{
-	    if (! TriangulateLoops (le - ls - skips, loops, lin.points,
+	    if (! TriangulateNestedLoops (le - ls - skips, loops, lin.points,
 		    (normal) ? normal + f : NULL, lin.npoints, ltris, &ftri, lin.nDim))
 	    {
 #if TRIANGULATE_ALWAYS
