@@ -6,10 +6,15 @@
 /*    "IBM PUBLIC LICENSE - Open Visualization Data Explorer"          */
 /***********************************************************************/
 /*
- * $Header: /src/master/dx/src/exec/dxmods/_tiff.c,v 1.11 2003/07/11 05:50:34 davidt Exp $
+ * $Header: /src/master/dx/src/exec/dxmods/_tiff.c,v 1.13 2006/01/04 22:00:51 davidt Exp $
  */
 
 #include <dxconfig.h>
+
+#if defined(HAVE_STRING_H)
+#include <string.h>
+#endif
+
 #include <dx/dx.h>
 
 
@@ -1738,7 +1743,7 @@ Field _dxf_InputTIFF
             goto error;
         else
         {
-            setval tmp_integer;
+            setval tmp_integer = {0, 0};
             int    remote_data = -1;
 
             /*
