@@ -9,6 +9,11 @@
 #include <dxconfig.h>
 
 #include <ctype.h>
+
+#if defined(HAVE_STRING_H)
+#include <string.h>
+#endif
+
 #include <dx/dx.h>
 #include "autoaxes.h"
 #include "plot.h"
