@@ -23,6 +23,18 @@ static Matrix Identity = {
                               { 0.0, 0.0, 1.0 }}
                          };
 
+#if defined(DX_NATIVE_WINDOWS)
+/* This structure is defined to allow PostMessage to send a Windows
+ * message back to a window with the information needed to extract
+ * the actual image. 
+ */
+typedef struct _WindowsPixels {
+	int numBytes;
+	int width;
+	int height;
+	byte * pixels; } WindowsPixels;
+#endif
+
 #if 0
 #include <dl.h>
 #include <sys/stat.h>
@@ -346,17 +358,28 @@ m_Display(Object *in, Object *out)
 		uint DX_DISPLAYREADY;
 		HWND window;
 		char *win = arg2;
-		int bytes;
+		unsigned char* bytes;
+		WindowsPixels wp;
+		int width, height;
 
 		DX_DISPLAYREADY = RegisterWindowMessage("DX_DISPLAY_READY");
 		win+=2;
 		if(ui_window && !message(image, arg2, buttonState, ddcamera, object))
 			goto error;
 		// If doing 64 bit, will need to worry about changing atoi to atoi64
+		if (!DXGetImageBounds(image, NULL, NULL, &width, &height))
+            goto error;
+
 		bytes = _dxf_GetWindowsPixels(image, NULL);
+		wp.numBytes = width * height * 3;
+		wp.pixels = bytes;
+		wp.width = width;
+		wp.height = height;
+		printf("pixels ptr: %p\n", wp.pixels);
+		fflush(stdout);
 		window = (HWND) atoi(win); //parse after ## of arg1
 		if(window && bytes) {
-			if(PostMessage(window, DX_DISPLAYREADY, bytes, 0)==0){
+			if(PostMessage(window, DX_DISPLAYREADY, &wp, 0)==0){
 				/* Error */
 				TCHAR szBuf[80]; 
 				LPVOID lpMsgBuf;
