@@ -5,13 +5,16 @@
 /* This code licensed under the                                        */
 /*    "IBM PUBLIC LICENSE - Open Visualization Data Explorer"          */
 /***********************************************************************/
+/*
+ * $Header: /src/master/dx/src/exec/dxmods/fourier.c,v 1.7 2006/01/03 17:02:22 davidt Exp $
+ */
+
 
 #include <dxconfig.h>
 
-
-/*
- * $Header: /src/master/dx/src/exec/dxmods/fourier.c,v 1.6 2003/07/11 05:50:35 davidt Exp $
- */
+#if defined(HAVE_STRING_H)
+#include <string.h>
+#endif
 
 #include <math.h>
 #include "unpart.h"
