@@ -12,10 +12,10 @@
 
 
 static Point points[ARRW2DPTS] = {
- {  0.0000000000,      0.0000000000,   0.0 }, 
- {  0.0000000000,      1.0000000000,   0.0 },  
- { -0.2500000000,      0.8000000000,   0.0 }, 
- {  0.2500000000,      0.8000000000,   0.0 }
+ {  0.0000000000F,      0.0000000000F,   0.0F }, 
+ {  0.0000000000F,      1.0000000000F,   0.0F },  
+ { -0.2500000000F,      0.8000000000F,   0.0F }, 
+ {  0.2500000000F,      0.8000000000F,   0.0F }
 };
    
 static Line lines[] = {
