@@ -8,16 +8,16 @@
 #define CIRCLE10PTS 10 
 #define CIRCLE10TRS 8 
 static Point points[CIRCLE10PTS] = {
- {  0.8090170026,      0.5877852440,      0.0000000000 },
- {  0.3090169728,      0.9510565400,      0.0000000000 },
- { -0.3090170324,      0.9510564804,      0.0000000000 },
- { -0.8090170622,      0.5877851844,      0.0000000000 },
- { -1.0000000000,     -0.0000000874,      0.0000000000 },
- { -0.8090169430,     -0.5877853632,      0.0000000000 },
- { -0.3090170920,     -0.9510564804,      0.0000000000 },
- {  0.3090171218,     -0.9510564804,      0.0000000000 },
- {  0.8090172410,     -0.5877849460,      0.0000000000 },
- {  1.0000000000,      0.0000000000,      0.0000000000 }
+ {  0.8090170026F,      0.5877852440F,      0.0000000000F },
+ {  0.3090169728F,      0.9510565400F,      0.0000000000F },
+ { -0.3090170324F,      0.9510564804F,      0.0000000000F },
+ { -0.8090170622F,      0.5877851844F,      0.0000000000F },
+ { -1.0000000000F,     -0.0000000874F,      0.0000000000F },
+ { -0.8090169430F,     -0.5877853632F,      0.0000000000F },
+ { -0.3090170920F,     -0.9510564804F,      0.0000000000F },
+ {  0.3090171218F,     -0.9510564804F,      0.0000000000F },
+ {  0.8090172410F,     -0.5877849460F,      0.0000000000F },
+ {  1.0000000000F,      0.0000000000F,      0.0000000000F }
 };
 static Triangle triangles[] = {
  {   0,     1,     2 },
