@@ -8,10 +8,10 @@
 #define CIRCLE4PTS 4 
 #define CIRCLE4TRS 2 
 static Point points[CIRCLE4PTS] = {
- { -0.0000000437,      1.0000000000,      0.0000000000 },
- { -1.0000000000,     -0.0000000874,      0.0000000000 },
- {  0.0000000119,     -1.0000000000,      0.0000000000 },
- {  1.0000000000,      0.0000000000,      0.0000000000 }
+ { -0.0000000437F,      1.0000000000F,      0.0000000000F },
+ { -1.0000000000F,     -0.0000000874F,      0.0000000000F },
+ {  0.0000000119F,     -1.0000000000F,      0.0000000000F },
+ {  1.0000000000F,      0.0000000000F,      0.0000000000F }
 };
 static Triangle triangles[] = {
   {  0,     1,     2 }, 
