@@ -8,12 +8,12 @@
 #define CIRCLE6PTS 6 
 #define CIRCLE6TRS 4 
 static Point points[CIRCLE6PTS] = {
- {  0.4999999702,      0.8660254478,      0.0000000000 },
- { -0.5000000596,      0.8660253882,      0.0000000000 },
- { -1.0000000000,     -0.0000000874,      0.0000000000 },
- { -0.4999999106,     -0.8660254478,      0.0000000000 },
- {  0.4999999106,     -0.8660254478,      0.0000000000 },
- {  1.0000000000,      0.0000000000,      0.0000000000 }
+ {  0.4999999702F,      0.8660254478F,      0.0000000000F },
+ { -0.5000000596F,      0.8660253882F,      0.0000000000F },
+ { -1.0000000000F,     -0.0000000874F,      0.0000000000F },
+ { -0.4999999106F,     -0.8660254478F,      0.0000000000F },
+ {  0.4999999106F,     -0.8660254478F,      0.0000000000F },
+ {  1.0000000000F,      0.0000000000F,      0.0000000000F }
 };
 static Triangle triangles[] = {
  {   0,     1,     2 },
