@@ -8,14 +8,14 @@
 #define CIRCLE8PTS 8 
 #define CIRCLE8TRS 6 
 static Point points[CIRCLE8PTS] = {
- {  0.7071067691,      0.7071067691,      0.0000000000 },
- { -0.0000000437,      1.0000000000,      0.0000000000 },
- { -0.7071067691,      0.7071067691,      0.0000000000 },
- { -1.0000000000,     -0.0000000874,      0.0000000000 },
- { -0.7071066499,     -0.7071068883,      0.0000000000 },
- {  0.0000000119,     -1.0000000000,      0.0000000000 },
- {  0.7071070075,     -0.7071065307,      0.0000000000 },
- {  1.0000000000,      0.0000000000,      0.0000000000 }
+ {  0.7071067691F,      0.7071067691F,      0.0000000000F },
+ { -0.0000000437F,      1.0000000000F,      0.0000000000F },
+ { -0.7071067691F,      0.7071067691F,      0.0000000000F },
+ { -1.0000000000F,     -0.0000000874F,      0.0000000000F },
+ { -0.7071066499F,     -0.7071068883F,      0.0000000000F },
+ {  0.0000000119F,     -1.0000000000F,      0.0000000000F },
+ {  0.7071070075F,     -0.7071065307F,      0.0000000000F },
+ {  1.0000000000F,      0.0000000000F,      0.0000000000F }
 };
 static Triangle triangles[] = {
  {   0,     1,     2 },
