@@ -12,8 +12,8 @@
 
 
 static Point points[NDDL2DPTS] = {
- {  0.0000000000,      0.0000000000,  0.0 },
- {  0.0000000000,      1.0000000000,  0.0 },
+ {  0.0000000000F,      0.0000000000F,  0.0F },
+ {  0.0000000000F,      1.0000000000F,  0.0F },
 };
    
 static Line lines[NDDL2DLNS] = {
