@@ -8,12 +8,12 @@
 #define PNTPTS 6 
 #define PNTLNS 3 
 static Point points[PNTPTS] = {
- { -0.5000000000,      0.0000000000,      0.0000000000 }, 
- {  0.5000000000,      0.0000000000,      0.0000000000 },
- {  0.0000000000,     -0.5000000000,      0.0000000000 },
- {  0.0000000000,      0.5000000000,      0.0000000000 },
- {  0.0000000000,      0.0000000000,     -0.5000000000 },
- {  0.0000000000,      0.0000000000,      0.5000000000 }
+ { -0.5000000000F,      0.0000000000F,      0.0000000000F }, 
+ {  0.5000000000F,      0.0000000000F,      0.0000000000F },
+ {  0.0000000000F,     -0.5000000000F,      0.0000000000F },
+ {  0.0000000000F,      0.5000000000F,      0.0000000000F },
+ {  0.0000000000F,      0.0000000000F,     -0.5000000000F },
+ {  0.0000000000F,      0.0000000000F,      0.5000000000F }
 };
 
 #include <dxconfig.h>
