@@ -10,7 +10,11 @@
 
 
 #include <dx/dx.h>
-#include "math.h"
+#include <math.h>
+
+#if defined(HAVE_STRING_H)
+#include <string.h>
+#endif
 
 #define ZOFFSET         1.0
 #define SENSITIVITY	4.0
@@ -126,6 +130,9 @@ static Field  PickBufToField(PickBuf *, Matrix);
 static Field  GetFirstHits(Field);
 static Error  PickInterpolate(Object, Field, int);
 
+extern Error _dxfLoadStereoModes();
+extern Error _dxfInitializeStereoCameraMode(void *, Object);
+
 #define CACHE_PICKS	1
 #define NO_CACHE_PICKS	0
 
@@ -665,7 +672,7 @@ error:
 extern Error _dxfGetStereoCameras(void *, Camera, Camera *, Camera *);
 extern void *_dxfGetStereoWindowInfo(char *, void *, void *);
 
-m_StereoPick(Object *in, Object *out)
+Error m_StereoPick(Object *in, Object *out)
 {
     Camera camera, lcamera, rcamera;
     char *where;
