@@ -8,6 +8,9 @@
 
 #include <dxconfig.h>
 
+#if defined(HAVE_STRING_H)
+#include <string.h>
+#endif
 
 #include <stddef.h>
 #include "interact.h" 
