@@ -20,6 +20,10 @@
 #include <ctype.h>
 #endif
 
+#if defined(HAVE_STRING_H)
+#include <string.h>
+#endif
+
 #include <dx/dx.h>
 #include <math.h>
 
