@@ -5,17 +5,15 @@
 /* This code licensed under the                                        */
 /*    "IBM PUBLIC LICENSE - Open Visualization Data Explorer"          */
 /***********************************************************************/
+/* 
+ * $Header: /src/master/dx/src/exec/hwrender/hwInitScreen.c,v 1.8 2006/01/03 17:02:27 davidt Exp $
+ */
 
 #include <dxconfig.h>
 
 
 #define tdmInitScreen_c
 
-#ifndef	lint
-static char *rcsid[] = {"$Header: /src/master/dx/src/exec/hwrender/hwInitScreen.c,v 1.6 2003/07/11 05:50:37 davidt Exp $"};
-#endif
-
-
 /*
  * Environment:		Risc System 6000
  * Current Source:	$Source: /src/master/dx/src/exec/hwrender/hwInitScreen.c,v $
@@ -41,7 +39,10 @@ static char *rcsid[] = {"$Header: /src/master/dx/src/exec/hwrender/hwInitScreen.
 
 typedef Error (*Handler)(int, Pointer);
 
-extern _dxfCacheState(char *, dxObject, dxObject, int);
+extern void _dxfCacheState(char *, dxObject, dxObject, int);
+extern void _dxfFreeStack (void *stack);
+extern void _dxfDeletePortHandle(tdmPortHandleP);
+extern void _dxf_DeleteObjectHash(HashTable);
 
 Error
 _dxfInitRenderObject(WinP win)
@@ -210,6 +211,9 @@ _dxfEndSWRenderPass (WinP win, Field image)
 }
 
 #if !defined(DX_NATIVE_WINDOWS)
+
+extern void _dxfSetXError (Display *dpy, XErrorEvent *event);
+
 static int
 _HandleExitErrors (Display *dpy, XErrorEvent *rep)
 {
