@@ -5,12 +5,18 @@
 /* This code licensed under the                                        */
 /*    "IBM PUBLIC LICENSE - Open Visualization Data Explorer"          */
 /***********************************************************************/
+/*
+ * $Header: /src/master/dx/src/exec/hwrender/hwInteractor.c,v 1.6 2006/01/03 17:02:27 davidt Exp $"  ;
+ */
 
 #include <dxconfig.h>
 
+#if defined(HAVE_STRINGS_H)
+#include <strings.h>
+#endif
 
-#ifndef lint
-static char rcsid[] = "$Header: /src/master/dx/src/exec/hwrender/hwInteractor.c,v 1.4 2002/03/21 02:59:10 rhh Exp $"  ;
+#if defined(HAVE_STRING_H)
+#include <string.h>
 #endif
 
 /*---------------------------------------------------------------------------*\
@@ -171,12 +177,14 @@ _dxfAllocateInteractor (tdmInteractorWin W, int size)
 
   if (! I) goto error ;
   
-  if (size)
+  if (size) {
       /* allocate interactor private data */
-      if (! (PRIVATE(I) = tdmAllocateLocal(size)))
+      if (! (PRIVATE(I) = tdmAllocateLocal(size))) {
           goto error ;
-      else
+      } else {
           bzero ((char *) PRIVATE(I), size) ;
+      }
+  }
 
   WINDOW(I) = W ;
   AUX(I) = (tdmInteractor) 0 ;
@@ -392,20 +400,21 @@ _PushInteractorCamera (tdmInteractorCam *stack, tdmInteractorCam new)
       p->next = (tdmInteractorCam) 0 ;
     }
 
-  if (! new)
+  if (! new) {
       /* allocate new camera */
-      if (new = (tdmInteractorCam) tdmAllocateLocal(sizeof(tdmInteractorCamT)))
-          if (*stack)
+      if ( (new = (tdmInteractorCam) tdmAllocateLocal(sizeof(tdmInteractorCamT))) ) {
+          if (*stack) {
               /* copy current top */
               memcpy ((void *)new, (void *)*stack, sizeof(tdmInteractorCamT)) ;
-          else
+          } else {
               /* init new camera */
               bzero ((char *)new, sizeof(tdmInteractorCamT)) ;
-      else
-        {
+          }
+      } else {
           EXIT(("out of memory"));
           return 0 ;
-        }
+      }
+  }
 
   new->next = *stack ;
   *stack = new ;
@@ -660,7 +669,7 @@ _dxfSetInteractorViewInfo (tdmInteractorWin W,
                                         (f[2]-t[2])*(f[2]-t[2]))) ;
 
   /*  !!!!!!! This is very questionable coding style if it's correct !!!!! */
-  if (C->projection = proj)
+  if ( (C->projection = proj) )
     {
       /* perspective */
       C->fov = fov ;
