@@ -5,24 +5,25 @@
 /* This code licensed under the                                        */
 /*    "IBM PUBLIC LICENSE - Open Visualization Data Explorer"          */
 /***********************************************************************/
+/*
+ * $Source: /src/master/dx/src/exec/hwrender/hwMatrix.c,v $
+ */
 
 #include <dxconfig.h>
 
-
-/*
- $Source: /src/master/dx/src/exec/hwrender/hwMatrix.c,v $
- */
+#if defined(HAVE_STRINGS_H)
+#include <strings.h>
+#endif
 
 #include <stdio.h>
 #include <math.h>
 
-#include "hwDeclarations.h"
-#include "hwMatrix.h"
 #ifndef STANDALONE
 #include "hwMemory.h"
 #endif
+#include "hwDeclarations.h"
+#include "hwMatrix.h"
 #include "hwPortLayer.h"
-
 #include "hwDebug.h"
 
 /*
