@@ -5,13 +5,20 @@
 /* This code licensed under the                                        */
 /*    "IBM PUBLIC LICENSE - Open Visualization Data Explorer"          */
 /***********************************************************************/
+/* $Source: /src/master/dx/src/exec/hwrender/hwQmesh.c,v $
+ */
 
 #include <dxconfig.h>
 
+#if defined(HAVE_STRINGS_H)
+#include <strings.h>
+#endif
+
+#if defined(HAVE_STRING_H)
+#include <string.h>
+#endif
 
 #define tdmQmesh_c 
-/* $Source: /src/master/dx/src/exec/hwrender/hwQmesh.c,v $
- */
 
 #include <stdio.h>
 #include "hwDeclarations.h"
@@ -301,7 +308,7 @@ static Quadruple
 
 #define AllocateAndCopyQstripPointArray()			             \
 {                                                                            \
-if (stripArray[nStrips].point = (int *)tdmAllocate(nPtsInStrip*sizeof(int))) \
+if ( (stripArray[nStrips].point = (int *)tdmAllocate(nPtsInStrip*sizeof(int))) ) \
   {                                                                          \
     bcopy (point, stripArray[nStrips].point, nPtsInStrip * sizeof(int)) ;    \
     stripArray[nStrips].points = nPtsInStrip ;                               \
