@@ -8,7 +8,9 @@
 
 #include <dxconfig.h>
 
-
+#if defined(HAVE_STRING_H)
+#include <string.h>
+#endif
 
 #include "hwDeclarations.h"
 #include "hwXfield.h"
@@ -279,7 +281,7 @@ _expandOpacityMap(Field tf, ubyte omap[256] )
     }
 
     if ( (type == TYPE_FLOAT &&
-	  (rank == 0 || rank == 1 && shape[0] == 1)) )
+	  (rank == 0 || (rank == 1 && shape[0] == 1) )) )
     {
 	float *map_src = (float *)DXGetArrayData(array);
 
@@ -374,7 +376,7 @@ _getTexture_Field(Texture t)
 	}
 	else {
     	    if (! (o_type == TYPE_FLOAT &&
-    	          (o_rank == 0 || o_rank == 1 && o_shape[0] == 1)) ) {
+    	          (o_rank == 0 || (o_rank == 1 && o_shape[0] == 1) )) ) {
 		DXSetError(ERROR_MISSING_DATA, 
 		    "opacities for a direct color texture map must be float");
 		goto error;
@@ -411,12 +413,12 @@ _getTexture_Field(Texture t)
 	    int i;
 	    ubyte *dst = t->pixels;
 	    float *c_src = (float *)DXGetArrayData(colors);
-	    float *o_src;
+	    float *o_src = NULL;
 	    
 	    if ( opac ) {
 	        o_src = (float *)DXGetArrayData(opac);
 		if ( ! (o_type == TYPE_FLOAT &&
-			(o_rank == 0 || o_rank == 1 && o_shape[0] == 1)) ) {
+			(o_rank == 0 || (o_rank == 1 && o_shape[0] == 1) )) ) {
 		    DXSetError(ERROR_MISSING_DATA, 
 		     "opacities for a direct color texture map must be float");
 		    goto error;
@@ -440,12 +442,12 @@ _getTexture_Field(Texture t)
 	/*  Handle ubyte colors w/ float[3] or ubyte[3] colormap    */
 	/*    (w/ optional ubyte opacities with float opacity map)  */
         else if (type == TYPE_UBYTE &&
-                 (rank == 0 || rank == 1 && shape[0] == 1))
+                 (rank == 0 || (rank == 1 && shape[0] == 1) ))
 	{
 	    int i;
 	    ubyte *dst = t->pixels;
 	    ubyte *c_src = (ubyte *)DXGetArrayData(colors);
-	    ubyte *o_src;
+	    ubyte *o_src = NULL;
 	    ubyte cmap[768], omap[256];
 
 	    if (!_expandColorMap(tf, cmap))
@@ -453,7 +455,7 @@ _getTexture_Field(Texture t)
 
 	    if ( opac ) {
 		if ( !(o_type == TYPE_UBYTE &&
-		       (o_rank == 0 || o_rank == 1 && o_shape[0] == 1)) ) {
+		       (o_rank == 0 || (o_rank == 1 && o_shape[0] == 1) )) ) {
 		    DXSetError(ERROR_MISSING_DATA, 
 			"indirect texture map opacities must be scalar ubytes");
 		    goto error;
@@ -604,14 +606,14 @@ _getTexture_CompositeField(Texture t)
 	{
 	    int j, k;
 	    ubyte *c_src = (ubyte *)DXGetArrayData(colors);
-	    float *o_src;
+	    float *o_src = NULL;
 	    ubyte *dst = t->pixels + Bpp*((memberOffsets[0]*counts[1])
 					     + memberOffsets[1]);
 	    int dst_stride = Bpp*(counts[1] - memberCounts[1]);
 
 	    if ( opac ) {
 		if (! (o_type == TYPE_FLOAT &&
-		      (o_rank == 0 || o_rank == 1 && o_shape[0] == 1)) ) {
+		      (o_rank == 0 || (o_rank == 1 && o_shape[0] == 1) )) ) {
 		    DXSetError(ERROR_MISSING_DATA, 
 		      "opacities for a direct color texture map must be float");
 		    goto error;
@@ -639,14 +641,14 @@ _getTexture_CompositeField(Texture t)
 	{
 	    int j, k;
 	    float *c_src = (float *)DXGetArrayData(colors);
-	    float *o_src;
+	    float *o_src = NULL;
 	    ubyte *dst = t->pixels + Bpp*((memberOffsets[0]*counts[1])
 					     + memberOffsets[1]);
 	    int dst_stride = Bpp*(counts[1] - memberCounts[1]);
 
 	    if ( opac ) {
 		if (! (o_type == TYPE_FLOAT &&
-		      (o_rank == 0 || o_rank == 1 && o_shape[0] == 1)) ) {
+		      (o_rank == 0 || (o_rank == 1 && o_shape[0] == 1) )) ) {
 		    DXSetError(ERROR_MISSING_DATA, 
 		      "opacities for a direct color texture map must be float");
 		    goto error;
@@ -672,12 +674,12 @@ _getTexture_CompositeField(Texture t)
 	/*  Handle ubyte colors w/ float[3] or ubyte[3] colormap    */
 	/*    (w/ optional ubyte opacities with float opacity map)  */
 	else if (type == TYPE_UBYTE &&
-	    (rank == 0 || rank == 1 && shape[0] == 1))
+	    (rank == 0 || (rank == 1 && shape[0] == 1) ))
 	{
 	    int j, k;
 	    ubyte cmap[768], omap[256];
 	    ubyte *c_src = (ubyte *)DXGetArrayData(colors);
-	    ubyte *o_src;
+	    ubyte *o_src = NULL;
 	    int dst_stride = Bpp*(counts[1] - memberCounts[1]);
 	    ubyte *dst = t->pixels + Bpp*((memberOffsets[0]*counts[1])
 					     + memberOffsets[1]);
@@ -687,7 +689,7 @@ _getTexture_CompositeField(Texture t)
 
 	    if ( opac ) {
 		if ( !(o_type == TYPE_UBYTE &&
-		       (o_rank == 0 || o_rank == 1 && o_shape[0] == 1)) ) {
+		       (o_rank == 0 || (o_rank == 1 && o_shape[0] == 1) )) ) {
 		    DXSetError(ERROR_MISSING_DATA, 
 			"indirect texture map opacities must be scalar ubytes");
 		    goto error;
