@@ -8,6 +8,9 @@
 
 #include <dxconfig.h>
 
+#if defined(HAVE_STRING_H)
+#include <string.h>
+#endif
 
 #include <stdio.h>
 #include <math.h>
@@ -27,7 +30,10 @@
 
 typedef float MATRIX[4][4];
 
-       void _dxf_computeMatrix(float *, float *, float *, float, MATRIX *);
+extern Error DXNotifyRegistered(char *name);
+extern Error DXNotifyRegisteredNoExecute(char *name);
+
+void _dxf_computeMatrix(float *, float *, float *, float, MATRIX *);
 
 static void UserDoubleClick(tdmInteractor, int, int, tdmInteractorReturn *);
 static void UserStartStrokeP(tdmInteractor, int, int, int, int);
