@@ -8,7 +8,6 @@
 
 #include <dxconfig.h>
 
-
 #define tdmWindow_c
 
 #if defined(DX_NATIVE_WINDOWS)
@@ -36,6 +35,12 @@
 
 #include "opengl/hwPortOGL.h"
 
+#if defined(HAVE_CTYPE_H)
+#include <ctype.h>
+#else
+extern int isdigit (int);
+#endif
+
 extern int GLTEST();
 
 typedef struct _OGLWindowThreadParams
@@ -57,6 +62,7 @@ static Error  _tdmResizeImage(WinP win) ;
 Error  _tdmResizeWindow(WinP win, int w, int h, int *change) ;
 static void   _tdmClearWindow(WinP win) ;
 static void   _tdmCleanupChild(tdmChildGlobalP childGlobals) ;
+int _dxfUIType(char *);
 
 static void
 StartStroke(OGLWindow *oglw, int x0, int y0, int button)
@@ -772,7 +778,7 @@ error:
 }
 
 /****************************** END WINDOWS *********************************/
-#else
+#else /* DX_NATIVE_WINDOWS */
 
 #define FLING_TIMEOUT 3
 #define FLING_GNOMON_FEECHURE
@@ -788,7 +794,19 @@ error:
 #include <stdio.h>
 #include <math.h>
 #include <time.h>
+#include <X11/Xlib.h>
 #include <X11/Xatom.h>
+#include <X11/Xutil.h>
+
+#if defined(HAVE_STRING_H)
+#include <string.h>
+#endif
+
+#if defined(HAVE_CTYPE_H)
+#include <ctype.h>
+#else
+extern int isdigit (int);
+#endif
 
 #include "hwDeclarations.h"
 #include "hwWindow.h"
@@ -828,6 +846,10 @@ _tdmCleanupChild(tdmChildGlobalP childGlobals) ;
 static Window
 _getTopLevelShell (Display *dpy, Window w) ;
 
+int _dxfUIType(char *);
+extern Error _dxfDraw (void*, dxObject, Camera, int);
+
+
 /*
 *  These atoms are used by the window manager to notify us if we're about
 *  to get killed (eg, evil user hits "close" item on Motif window menu).
@@ -1440,7 +1462,7 @@ GL_WINDOW = TRUE;
                     ev.xany.window = tmp;
                 } else {
                     char buf[32];
-                    XLookupString(&ev, buf, 32, NULL, NULL);
+                    XLookupString(&(ev.xkey), buf, 32, NULL, NULL);
                     if (buf[0])
                         tdmKeyStruck(globals->CrntInteractor, ev.xkey.x, ev.xkey.y, buf[0], ev.xkey.state);
                 }
@@ -2071,8 +2093,6 @@ _dxfTryRestoreBuffer (WinP win)
     _dxf_SWAP_BUFFERS(PORT_CTX, XWINID);
 #endif
 
-done:
-
     /* If we restored from a (partialially) invalid buffer, make sure we
     * still refresh.
     */
