@@ -8,6 +8,9 @@
 
 #include <dxconfig.h>
 
+#if defined(HAVE_STRING_H)
+#include <string.h>
+#endif
 
 /*---------------------------------------------------------------------------*\
  $Source: /src/master/dx/src/exec/hwrender/opengl/hwInteractorEchoOGL.c,v $
