@@ -5,17 +5,16 @@
 /* This code licensed under the                                        */
 /*    "IBM PUBLIC LICENSE - Open Visualization Data Explorer"          */
 /***********************************************************************/
-/*********************************************************************/
-/*                     I.B.M. CONFIENTIAL                           */
-/*********************************************************************/
-
-#include <dxconfig.h>
-
-
 /*---------------------------------------------------------------------------*\
  $Source: /src/master/dx/src/exec/hwrender/opengl/hwPortOGL.c,v $
 \*---------------------------------------------------------------------------*/
 
+#include <dxconfig.h>
+
+#if defined(HAVE_STRING_H)
+#include <string.h>
+#endif
+
 #define STRUCTURES_ONLY
 #include "../hwDeclarations.h"
 #include "../hwWindow.h"
@@ -44,6 +43,10 @@
 #include <x11/xlibxtra.h>
 #endif
 
+extern Error _dxf_dither(dxObject, int, int, int, 
+	int, void *, unsigned char *);
+extern Error _dxfExportHwddVersion(int version);
+
 #if defined (alphax) || defined(sgi) || defined(solaris)
 #  if !defined (DEBUG)
 #     include <dlfcn.h>
@@ -872,22 +875,39 @@ static void _dxf_INIT_RENDER_PASS (void *win, int bufferMode, int zBufferMode)
   SAVE_BUF_VALID = FALSE ;
 
   OGL_FAIL_ON_ERROR(_dxf_INIT_RENDER_PASS);
+
+  glEnable(GL_BLEND);
+  OGL_FAIL_ON_ERROR(glEnableBlend);
+  glBlendFunc(GL_SRC_ALPHA, GL_ONE_MINUS_SRC_ALPHA);
+  OGL_FAIL_ON_ERROR(glBlendFunc);
+  //glAlphaFunc(GL_GREATER, 0.0);
+  //OGL_FAIL_ON_ERROR(glAlphaFunc);
+
   EXIT((""));
 }
 
-#if defined(DX_NATIVE_WINDOWS)
+/* #if defined(DX_NATIVE_WINDOWS) */
 static void _dxf_END_RENDER_PASS(void *win)
 {
+#if defined(DX_NATIVE_WINDOWS)
+	OGLWindow *oglw;
+#endif
 	DEFWINDATA(win) ;
 	DEFPORT(PORT_HANDLE) ;
-	OGLWindow *oglw = GetOGLWPtr(XWINID);
+	glDisable(GL_BLEND);
+	OGL_FAIL_ON_ERROR(_dxf_END_RENDER_PASS);
+
+#if defined(DX_NATIVE_WINDOWS)
+	oglw = GetOGLWPtr(XWINID);
 	
 	glFlush();
 	SwapBuffers(OGLHDC);
 	EndPaint(XWINID, &oglw->ps);
-}
 #endif
 
+}
+/* #endif */
+
 static void _dxf_SET_VIEWPORT (void *ctx,
 			       int left, int right, int bottom, int top)
 {
@@ -1514,7 +1534,7 @@ static void _dxf_WRITE_APPROX_BACKSTORE(void *win, int camw, int camh)
   EXIT((""));
 }
 
-static void _dxf_WRITE_PIXEL_RECT(void* win, uint32 *buf,
+static void _dxf_WRITE_PIXEL_RECT(void* win, unsigned char *buf,
 				  int x, int y, int w, int h)
 {
   DEFWINDATA(win) ;
@@ -1546,7 +1566,7 @@ static Error _dxf_DRAW_IMAGE(void* win, dxObject image, translationO dummy)
   DEFWINDATA(win) ;
   DEFPORT(PORT_HANDLE) ;
   int		x,y,w,h ;
-  uint32 *pixels = NULL ;
+  unsigned char *pixels = NULL ;
   void * translation = OGLTRANSLATION ;
 
   ENTRY(("_dxf_DRAW_IMAGE(0x%x, 0x%x, 0x%x)", win, image, dummy));
