@@ -6,7 +6,7 @@
 #include "displayutil.h"
 Error
 _dxf_InitBuffer(struct buffer *b, enum pix_type pix_type,
-            int width, int height, int ox, int oy, RGBColor bkgnd)
+     int width, int height, int ox, int oy, RGBColor bkgnd)
 {
     register int i, n;
     int init;
@@ -17,32 +17,32 @@ _dxf_InitBuffer(struct buffer *b, enum pix_type pix_type,
     bg = bkgnd.g;
     bb = bkgnd.b;
     if (pix_type==pix_fast) {
-        b->buffer = DXAllocateLocal(n*sizeof(struct fast) + 16);
-        if (!b->buffer) {
-            DXResetError();
-            b->buffer = DXAllocate(n*sizeof(struct fast));
-            if (!b->buffer)
-                return ERROR;
-        }
-        b->u.fast = (struct fast *) ((((long)b->buffer)+16 -1) & ~(16 -1));
+ b->buffer = DXAllocateLocal(n*sizeof(struct fast) + 16);
+ if (!b->buffer) {
+     DXResetError();
+     b->buffer = DXAllocate(n*sizeof(struct fast));
+     if (!b->buffer)
+  return ERROR;
+ }
+ b->u.fast = (struct fast *) ((((long)b->buffer)+16 -1) & ~(16 -1));
     } else if (pix_type==pix_big) {
-        b->buffer = DXAllocateLocal(n*sizeof(struct big));
-        if (!b->buffer) {
-            DXResetError();
-            b->buffer = DXAllocate(n*sizeof(struct big));
-            if (!b->buffer)
-                return ERROR;
-        }
-        b->u.big = (struct big *) b->buffer;
+ b->buffer = DXAllocateLocal(n*sizeof(struct big));
+ if (!b->buffer) {
+     DXResetError();
+     b->buffer = DXAllocate(n*sizeof(struct big));
+     if (!b->buffer)
+  return ERROR;
+ }
+ b->u.big = (struct big *) b->buffer;
     } else if (pix_type==pix_zbuf) {
-        b->buffer = DXAllocateLocal(n*sizeof(struct zbuf));
-        if (!b->buffer) {
-            DXResetError();
-            b->buffer = DXAllocate(n*sizeof(struct zbuf));
-            if (!b->buffer)
-                return ERROR;
-        }
-        b->u.zbuf = (struct zbuf *) b->buffer;
+ b->buffer = DXAllocateLocal(n*sizeof(struct zbuf));
+ if (!b->buffer) {
+     DXResetError();
+     b->buffer = DXAllocate(n*sizeof(struct zbuf));
+     if (!b->buffer)
+  return ERROR;
+ }
+ b->u.zbuf = (struct zbuf *) b->buffer;
     }
     b->pix_type = pix_type;
     b->width = width;
@@ -54,52 +54,52 @@ _dxf_InitBuffer(struct buffer *b, enum pix_type pix_type,
     b->omin = DXPt(DXD_MAX_FLOAT, DXD_MAX_FLOAT, 0);
     b->omax = DXPt(DXD_MIN_FLOAT, DXD_MIN_FLOAT, 0);
     if (pix_type==pix_fast) {
-        struct fast *f;
-        for (i=0, f=b->u.fast; i<n; i++, f++) {
-            f->c.r = br;
-            f->c.g = bg;
-            f->c.b = bb;
-            f->z = -DXD_MAX_FLOAT;
-        }
+ struct fast *f;
+ for (i=0, f=b->u.fast; i<n; i++, f++) {
+     f->c.r = br;
+     f->c.g = bg;
+     f->c.b = bb;
+     f->z = -DXD_MAX_FLOAT;
+ }
     } else if (pix_type==pix_zbuf) {
-        struct zbuf *p;
-        for (i=0, p=b->u.zbuf; i<n; i++, p++)
-            p->z = -DXD_MAX_FLOAT;
+ struct zbuf *p;
+ for (i=0, p=b->u.zbuf; i<n; i++, p++)
+     p->z = -DXD_MAX_FLOAT;
     } else if (init==0) {
-        struct big *p;
-        for (i=0, p=b->u.big; i<n; i++, p++) {
-            p->c.r = br;
-            p->c.g = bg;
-            p->c.b = bb;
-            p->co.r = 0;
-            p->co.g = 0;
-            p->co.b = 0;
-            p->co.o = 0;
-            p->z = -DXD_MAX_FLOAT;
-            p->front = DXD_MAX_FLOAT;
-            p->back = -DXD_MAX_FLOAT;
-            p->in = 0;
-        }
+ struct big *p;
+ for (i=0, p=b->u.big; i<n; i++, p++) {
+     p->c.r = br;
+     p->c.g = bg;
+     p->c.b = bb;
+     p->co.r = 0;
+     p->co.g = 0;
+     p->co.b = 0;
+     p->co.o = 0;
+     p->z = -DXD_MAX_FLOAT;
+     p->front = DXD_MAX_FLOAT;
+     p->back = -DXD_MAX_FLOAT;
+     p->in = 0;
+ }
     } else if (init==1) {
-        static struct big init, *p;
-        static RGBColor c = {0, 0, 0};
-        static struct rgbo co = {0, 0, 0, 0};
-        init.c = c;
-        init.co = co;
-        init.z = -DXD_MAX_FLOAT;
-        init.front = DXD_MAX_FLOAT;
-        init.back = -DXD_MAX_FLOAT;
-        init.in = 0;
-        for (i=0, p=b->u.big; i<n; i++, p++)
-            *p = init;
+ static struct big init, *p;
+ static RGBColor c = {0, 0, 0};
+ static struct rgbo co = {0, 0, 0, 0};
+ init.c = c;
+ init.co = co;
+ init.z = -DXD_MAX_FLOAT;
+ init.front = DXD_MAX_FLOAT;
+ init.back = -DXD_MAX_FLOAT;
+ init.in = 0;
+ for (i=0, p=b->u.big; i<n; i++, p++)
+     *p = init;
     } else if (init==2) {
-        struct big *p;
-        memset(b->u.big, 0, n*sizeof(struct big));
-        for (i=0, p=b->u.big; i<n; i++, p++) {
-            p->z = -DXD_MAX_FLOAT;
-            p->front = DXD_MAX_FLOAT;
-            p->back = -DXD_MAX_FLOAT;
-        }
+ struct big *p;
+ memset(b->u.big, 0, n*sizeof(struct big));
+ for (i=0, p=b->u.big; i<n; i++, p++) {
+     p->z = -DXD_MAX_FLOAT;
+     p->front = DXD_MAX_FLOAT;
+     p->back = -DXD_MAX_FLOAT;
+ }
     }
     return OK;
 }
@@ -111,8 +111,8 @@ _dxf_BeginClipping(struct buffer *b)
     int n, i;
     n = b->width*b->height;
     for (i=0; i<n; i++) {
-        b->u.big[i].front = -DXD_MAX_FLOAT;
-        b->u.big[i].back = DXD_MAX_FLOAT;
+ b->u.big[i].front = -DXD_MAX_FLOAT;
+ b->u.big[i].back = DXD_MAX_FLOAT;
     }
     return OK;
 }
@@ -123,9 +123,9 @@ _dxfCapClipping(struct buffer *b, float nearPlane)
     struct big *pix= b->u.big;
     while (--n >= 0)
     {
-        if (pix->front == pix->back)
-            pix->front = nearPlane;
-        pix ++;
+ if (pix->front == pix->back)
+     pix->front = nearPlane;
+ pix ++;
     }
     return OK;
 }
@@ -135,13 +135,13 @@ _dxf_MergeBackIntoZ(struct buffer *b)
     int n, i;
     struct big *pix;
     if (b->merged)
-        return OK;
+ return OK;
     n = b->width*b->height;
     for (i=0, pix=b->u.big; i<n; i++, pix++)
-        if (pix->back > pix->z)
-            pix->z = pix->back;
-        else
-            pix->back = pix->z;
+ if (pix->back > pix->z)
+     pix->z = pix->back;
+ else
+     pix->back = pix->z;
     b->merged = 1;
     return OK;
 }
@@ -151,8 +151,8 @@ _dxf_EndClipping(struct buffer *b)
     int n, i;
     n = b->width*b->height;
     for (i=0; i<n; i++) {
-        b->u.big[i].front = DXD_MAX_FLOAT;
-        b->u.big[i].back = -DXD_MAX_FLOAT;
+ b->u.big[i].front = DXD_MAX_FLOAT;
+ b->u.big[i].back = -DXD_MAX_FLOAT;
     }
     return OK;
 }
@@ -166,62 +166,62 @@ _dxf_CopyBufferToImage(struct buffer *b, Field i, int xoff, int yoff)
     Array a;
     o = DXGetComponentAttribute(i, IMAGE, IMAGE_TYPE);
     if (o==O_FB_IMAGE)
-        return _dxf_CopyBufferToFBImage(b, i, xoff, yoff);
+ return _dxf_CopyBufferToFBImage(b, i, xoff, yoff);
     else if (o==O_X_IMAGE)
-        return _dxf_CopyBufferToPImage(b, i, xoff, yoff);
+ return _dxf_CopyBufferToPImage(b, i, xoff, yoff);
     else if (o)
-        DXErrorReturn(ERROR_BAD_PARAMETER, "#11600");
+ DXErrorReturn(ERROR_BAD_PARAMETER, "#11600");
     if (!DXGetImageSize(i, &iwidth, NULL))
-        return ERROR;
+ return ERROR;
     a = (Array)DXGetComponentValue(i, COLORS);
     if (! a)
-        return ERROR;
+ return ERROR;
     DXGetArrayInfo(a, NULL, &type, NULL, NULL, NULL);
     if (type == TYPE_FLOAT)
     {
-        if (b->pix_type == pix_fast)
-        {
-            { RGBColor *pixels = (RGBColor *)DXGetArrayData(a); RGBColor *t; register RGBColor *tt; struct fast *ff; register struct fast *f; ff = b->u.fast; tt = pixels + yoff*iwidth + xoff; for (y=0; y<bheight; y++) { for (x=0, f=ff, t=tt; x<bwidth; x++, f++, t++)
-            t->r = f->c.r, t->g = f->c.g, t->b = f->c.b;
-            ff += bwidth; tt += iwidth; } }
-        }
-        else if (b->pix_type == pix_big)
-        {
-            { RGBColor *pixels = (RGBColor *)DXGetArrayData(a); RGBColor *t; register RGBColor *tt; struct big *ff; register struct big *f; ff = b->u.big; tt = pixels + yoff*iwidth + xoff; for (y=0; y<bheight; y++) { for (x=0, f=ff, t=tt; x<bwidth; x++, f++, t++)
-            t->r = f->c.r, t->g = f->c.g, t->b = f->c.b;
-            ff += bwidth; tt += iwidth; } }
-        }
+ if (b->pix_type == pix_fast)
+ {
+     { RGBColor *pixels = (RGBColor *)DXGetArrayData(a); RGBColor *t; register RGBColor *tt; struct fast *ff; register struct fast *f; ff = b->u.fast; tt = pixels + yoff*iwidth + xoff; for (y=0; y<bheight; y++) { for (x=0, f=ff, t=tt; x<bwidth; x++, f++, t++)
+     t->r = f->c.r, t->g = f->c.g, t->b = f->c.b;
+     ff += bwidth; tt += iwidth; } }
+ }
+ else if (b->pix_type == pix_big)
+ {
+     { RGBColor *pixels = (RGBColor *)DXGetArrayData(a); RGBColor *t; register RGBColor *tt; struct big *ff; register struct big *f; ff = b->u.big; tt = pixels + yoff*iwidth + xoff; for (y=0; y<bheight; y++) { for (x=0, f=ff, t=tt; x<bwidth; x++, f++, t++)
+     t->r = f->c.r, t->g = f->c.g, t->b = f->c.b;
+     ff += bwidth; tt += iwidth; } }
+ }
     }
     else if (type == TYPE_UBYTE)
     {
-        if (b->pix_type == pix_fast)
-        {
-            { RGBByteColor *pixels = (RGBByteColor *)DXGetArrayData(a); RGBByteColor *t; register RGBByteColor *tt; struct fast *ff; register struct fast *f; ff = b->u.fast; tt = pixels + yoff*iwidth + xoff; for (y=0; y<bheight; y++) { for (x=0, f=ff, t=tt; x<bwidth; x++, f++, t++)
-            { t->r = (f->c.r >= 1.0) ? 255 : (f->c.r <= 0.0) ? 0 : 255 * f->c.r; t->g = (f->c.g >= 1.0) ? 255 : (f->c.g <= 0.0) ? 0 : 255 * f->c.g; t->b = (f->c.b >= 1.0) ? 255 : (f->c.b <= 0.0) ? 0 : 255 * f->c.b; }
-            ff += bwidth; tt += iwidth; } }
-        }
-        else if (b->pix_type == pix_big)
-        {
-            { RGBByteColor *pixels = (RGBByteColor *)DXGetArrayData(a); RGBByteColor *t; register RGBByteColor *tt; struct big *ff; register struct big *f; ff = b->u.big; tt = pixels + yoff*iwidth + xoff; for (y=0; y<bheight; y++) { for (x=0, f=ff, t=tt; x<bwidth; x++, f++, t++)
-            { t->r = (f->c.r >= 1.0) ? 255 : (f->c.r <= 0.0) ? 0 : 255 * f->c.r; t->g = (f->c.g >= 1.0) ? 255 : (f->c.g <= 0.0) ? 0 : 255 * f->c.g; t->b = (f->c.b >= 1.0) ? 255 : (f->c.b <= 0.0) ? 0 : 255 * f->c.b; }
-            ff += bwidth; tt += iwidth; } }
-        }
+ if (b->pix_type == pix_fast)
+ {
+     { RGBByteColor *pixels = (RGBByteColor *)DXGetArrayData(a); RGBByteColor *t; register RGBByteColor *tt; struct fast *ff; register struct fast *f; ff = b->u.fast; tt = pixels + yoff*iwidth + xoff; for (y=0; y<bheight; y++) { for (x=0, f=ff, t=tt; x<bwidth; x++, f++, t++)
+     { t->r = (f->c.r >= 1.0) ? 255 : (f->c.r <= 0.0) ? 0 : 255 * f->c.r; t->g = (f->c.g >= 1.0) ? 255 : (f->c.g <= 0.0) ? 0 : 255 * f->c.g; t->b = (f->c.b >= 1.0) ? 255 : (f->c.b <= 0.0) ? 0 : 255 * f->c.b; }
+     ff += bwidth; tt += iwidth; } }
+ }
+ else if (b->pix_type == pix_big)
+ {
+     { RGBByteColor *pixels = (RGBByteColor *)DXGetArrayData(a); RGBByteColor *t; register RGBByteColor *tt; struct big *ff; register struct big *f; ff = b->u.big; tt = pixels + yoff*iwidth + xoff; for (y=0; y<bheight; y++) { for (x=0, f=ff, t=tt; x<bwidth; x++, f++, t++)
+     { t->r = (f->c.r >= 1.0) ? 255 : (f->c.r <= 0.0) ? 0 : 255 * f->c.r; t->g = (f->c.g >= 1.0) ? 255 : (f->c.g <= 0.0) ? 0 : 255 * f->c.g; t->b = (f->c.b >= 1.0) ? 255 : (f->c.b <= 0.0) ? 0 : 255 * f->c.b; }
+     ff += bwidth; tt += iwidth; } }
+ }
     }
     a = (Array)DXGetComponentValue(i, "zbuffer");
     if (a)
     {
-        if (b->pix_type == pix_fast)
-        {
-            { float *z_pixels = (float *)DXGetArrayData(a); float *t; register float *tt; struct fast *ff; register struct fast *f; ff = b->u.fast; tt = z_pixels + yoff*iwidth + xoff; for (y=0; y<bheight; y++) { for (x=0, f=ff, t=tt; x<bwidth; x++, f++, t++)
-            *t = f->z;
-            ff += bwidth; tt += iwidth; } }
-        }
-        else if (b->pix_type == pix_big)
-        {
-            { float *z_pixels = (float *)DXGetArrayData(a); float *t; register float *tt; struct big *ff; register struct big *f; ff = b->u.big; tt = z_pixels + yoff*iwidth + xoff; for (y=0; y<bheight; y++) { for (x=0, f=ff, t=tt; x<bwidth; x++, f++, t++)
-            *t = f->z;
-            ff += bwidth; tt += iwidth; } }
-        }
+ if (b->pix_type == pix_fast)
+ {
+     { float *z_pixels = (float *)DXGetArrayData(a); float *t; register float *tt; struct fast *ff; register struct fast *f; ff = b->u.fast; tt = z_pixels + yoff*iwidth + xoff; for (y=0; y<bheight; y++) { for (x=0, f=ff, t=tt; x<bwidth; x++, f++, t++)
+     *t = f->z;
+     ff += bwidth; tt += iwidth; } }
+ }
+ else if (b->pix_type == pix_big)
+ {
+     { float *z_pixels = (float *)DXGetArrayData(a); float *t; register float *tt; struct big *ff; register struct big *f; ff = b->u.big; tt = z_pixels + yoff*iwidth + xoff; for (y=0; y<bheight; y++) { for (x=0, f=ff, t=tt; x<bwidth; x++, f++, t++)
+     *t = f->z;
+     ff += bwidth; tt += iwidth; } }
+ }
     }
     return OK;
 }
@@ -236,7 +236,7 @@ _dxf_CopyFace(struct buffer *b, int if_object)
     int i, j, x, y, nx, ny;
     struct big *pix, *p;
     if (b->fmax.x<b->fmin.x || b->fmax.y<b->fmin.y)
-        return OK;
+ return OK;
     x = (int)b->fmin.x;
     y = (int)b->fmin.y;
     nx = (int)b->fmax.x - x + 1;
@@ -248,20 +248,20 @@ _dxf_CopyFace(struct buffer *b, int if_object)
     if (if_object) if_object = IF_OBJECT;
     pix = b->u.big + y*b->width;
     for (i=0; i<ny; i++, pix+=b->width) {
-        for (j=0, p=pix+x; j<nx; j++, p++) {
-            int in = p->in;
-            if (in & IN_FACE) {
-                if (p->co.o>p->z && p->co.o<p->front && p->co.o>p->back) {
-                    p->c.r=p->co.r;
-                    p->c.g=p->co.g;
-                    p->c.b=p->co.b;
-                    p->z=p->co.o;
-                }
-                in &= ~IN_FACE;
-                in ^= if_object;
-                p->in = in;
-            }
-        }
+ for (j=0, p=pix+x; j<nx; j++, p++) {
+     int in = p->in;
+     if (in & IN_FACE) {
+  if (p->co.o>p->z && p->co.o<p->front && p->co.o>p->back) {
+      p->c.r=p->co.r;
+      p->c.g=p->co.g;
+      p->c.b=p->co.b;
+      p->z=p->co.o;
+  }
+  in &= ~IN_FACE;
+  in ^= if_object;
+  p->in = in;
+     }
+ }
     }
     return OK;
 }
@@ -280,16 +280,16 @@ _dxf_InterferenceObject(struct buffer *buf)
     if (ymin<0) ymin = 0; else if (ymin>=height) ymin = height;
     if (ymax<0) ymax = 0; else if (ymax>=height) ymax = height;
     for (y=ymin, pp=buf->u.big+y*width; y<ymax; y++, pp+=width) {
-        for (x=xmin, p=pp+xmin; x<xmax; x++, p++) {
-            int in = p->in;
-            if (in & IF_OBJECT) {
-                if (in & IF_UNION)
-                    in |= IF_INTERSECTION;
-                in |= IF_UNION;
-                in &= ~IF_OBJECT;
-                p->in = in;
-            }
-        }
+ for (x=xmin, p=pp+xmin; x<xmax; x++, p++) {
+     int in = p->in;
+     if (in & IF_OBJECT) {
+  if (in & IF_UNION)
+      in |= IF_INTERSECTION;
+  in |= IF_UNION;
+  in &= ~IF_OBJECT;
+  p->in = in;
+     }
+ }
     }
     return OK;
 }
@@ -390,7 +390,7 @@ static Array encode_8bit(Field image, translationP t)
  int segknt, totknt; 
  SegListSegment *seg; 
  SegList *seglist = NULL; 
- ubyte *segptr; 
+ ubyte *segptr=NULL; 
  int mask = 0; 
  
  a = (Array)DXGetComponentValue(image, "connections"); 
@@ -693,7 +693,7 @@ static Array encode_12bit(Field image, translationP t)
  int segknt, totknt; 
  SegListSegment *seg; 
  SegList *seglist = NULL; 
- ubyte *segptr; 
+ ubyte *segptr=NULL; 
  int mask = COLORMASK12; 
  
  a = (Array)DXGetComponentValue(image, "connections"); 
@@ -996,7 +996,7 @@ static Array encode_24bit(Field image, translationP t)
  int segknt, totknt; 
  SegListSegment *seg; 
  SegList *seglist = NULL; 
- ubyte *segptr; 
+ ubyte *segptr=NULL; 
  int mask = COLORMASK24; 
  
  a = (Array)DXGetComponentValue(image, "connections"); 
@@ -1299,7 +1299,7 @@ static Array encode_32bit(Field image, translationP t)
  int segknt, totknt; 
  SegListSegment *seg; 
  SegList *seglist = NULL; 
- ubyte *segptr; 
+ ubyte *segptr=NULL; 
  int mask = 0; 
  
  a = (Array)DXGetComponentValue(image, "connections"); 
@@ -1602,7 +1602,7 @@ static Array encode_RGBColor(Field image, translationP t)
  int segknt, totknt; 
  SegListSegment *seg; 
  SegList *seglist = NULL; 
- ubyte *segptr; 
+ ubyte *segptr=NULL; 
  int mask = 0; 
  
  a = (Array)DXGetComponentValue(image, "connections"); 
@@ -1820,62 +1820,62 @@ _dxf_EncodeImage(Field image)
     Array a = (Array)DXGetComponentValue(image, IMAGE);
     if (! a)
     {
-        DXSetError(ERROR_INTERNAL, "invalid image field");
-        return NULL;
+ DXSetError(ERROR_INTERNAL, "invalid image field");
+ return NULL;
     }
     if (o)
-        translation = _dxf_GetXTranslation(o);
+ translation = _dxf_GetXTranslation(o);
     DXMarkTime("encode start");
     if (! DXGetArrayInfo(a, NULL, &t, &c, &r, &s))
-        return NULL;
+ return NULL;
     if (t == TYPE_UBYTE && (r == 0 || (r == 1 && s == 1)))
-        encodedimage = (Object)encode_8bit(image, translation);
+ encodedimage = (Object)encode_8bit(image, translation);
     else if (t == TYPE_USHORT && (r == 0 || (r == 1 && s == 1)))
-        encodedimage = (Object)encode_12bit(image, translation);
+ encodedimage = (Object)encode_12bit(image, translation);
     else if (t == TYPE_UINT && (r == 0 || (r == 1 && s == 1)))
-        encodedimage = (Object)encode_24bit(image, translation);
+ encodedimage = (Object)encode_24bit(image, translation);
     else if (t == TYPE_UBYTE && r == 1 && s == 4)
-        encodedimage = (Object)encode_32bit(image, translation);
+ encodedimage = (Object)encode_32bit(image, translation);
     else if (t == TYPE_FLOAT && (r == 1 && s == 3))
-        encodedimage = (Object)encode_RGBColor(image, translation);
+ encodedimage = (Object)encode_RGBColor(image, translation);
     else
-        encodedimage = DXCopy((Object)image, COPY_STRUCTURE);
+ encodedimage = DXCopy((Object)image, COPY_STRUCTURE);
     if (!encodedimage)
-        return NULL;
+ return NULL;
     if (! DXSetIntegerAttribute(encodedimage, "image tag",
-                                        (int)DXGetObjectTag((Object)image)))
+     (int)DXGetObjectTag((Object)image)))
     {
-        DXDelete(encodedimage);
-        return NULL;
+ DXDelete(encodedimage);
+ return NULL;
     }
     attr = DXGetAttribute((Object)image, "camera");
     if (attr)
-        if (! DXSetAttribute(encodedimage, "camera", attr))
-        {
-            DXDelete(encodedimage);
-            return NULL;
-        }
+ if (! DXSetAttribute(encodedimage, "camera", attr))
+ {
+     DXDelete(encodedimage);
+     return NULL;
+ }
     attr = DXGetAttribute((Object)image, "object box");
     if (attr)
-        if (! DXSetAttribute(encodedimage, "object box", attr))
-        {
-            DXDelete(encodedimage);
-            return NULL;
-        }
+ if (! DXSetAttribute(encodedimage, "object box", attr))
+ {
+     DXDelete(encodedimage);
+     return NULL;
+ }
     attr = DXGetComponentAttribute(image, IMAGE, IMAGE_TYPE);
     if (attr)
-        if (! DXSetAttribute(encodedimage, IMAGE_TYPE, attr))
-        {
-            DXDelete(encodedimage);
-            return NULL;
-        }
+ if (! DXSetAttribute(encodedimage, IMAGE_TYPE, attr))
+ {
+     DXDelete(encodedimage);
+     return NULL;
+ }
     attr = DXGetAttribute((Object)image, X_SERVER);
     if (attr)
-        if (! DXSetAttribute(encodedimage, X_SERVER, attr))
-        {
-            DXDelete(encodedimage);
-            return NULL;
-        }
+ if (! DXSetAttribute(encodedimage, X_SERVER, attr))
+ {
+     DXDelete(encodedimage);
+     return NULL;
+ }
     DXMarkTime("encode end");
     return encodedimage;
 }
@@ -1888,80 +1888,80 @@ _dxf_DecodeImage(Object encodedimage)
     attr = DXGetAttribute((Object)encodedimage, "encoding type");
     if (! attr)
     {
-        if (DXGetObjectClass(encodedimage) != CLASS_FIELD)
-        {
-            DXSetError(ERROR_DATA_INVALID, "invalid image");
-            return NULL;
-        }
-        image = (Field)DXCopy(encodedimage, COPY_STRUCTURE);
+ if (DXGetObjectClass(encodedimage) != CLASS_FIELD)
+ {
+     DXSetError(ERROR_DATA_INVALID, "invalid image");
+     return NULL;
+ }
+ image = (Field)DXCopy(encodedimage, COPY_STRUCTURE);
     }
     else
     {
-        if (DXGetObjectClass(encodedimage) != CLASS_ARRAY)
-        {
-            DXSetError(ERROR_DATA_INVALID, "invalid encoded image");
-            return NULL;
-        }
-        if (DXGetObjectClass(attr) != CLASS_STRING)
-        {
-            DXSetError(ERROR_INTERNAL, "invalid encoded image");
-            return NULL;
-        }
-        str = DXGetString((String)attr);
-        DXMarkTime("decode start");
-        if (! strcmp(str, "8bit"))
-            image = decode_8bit((Array)encodedimage);
-        else if (! strcmp(str, "12bit"))
-            image = decode_12bit((Array)encodedimage);
-        else if (! strcmp(str, "24bit"))
-            image = decode_24bit((Array)encodedimage);
-        else if (! strcmp(str, "32bit"))
-            image = decode_32bit((Array)encodedimage);
-        else if (! strcmp(str, "RGBColor"))
-            image = decode_RGBColor((Array)encodedimage);
-        else
-        {
-            DXSetError(ERROR_INTERNAL, "invalid encoded image");
-            return NULL;
-        }
-        attr = DXGetAttribute(encodedimage, "image tag");
-        if (! attr)
-        {
-            DXSetError(ERROR_INTERNAL, "missing image tag");
-            DXDelete((Object)image);
-            return NULL;
-        }
-        if (! DXSetAttribute((Object)image, "image tag", attr))
-        {
-            DXDelete((Object)image);
-            return NULL;
-        }
-        attr = DXGetAttribute(encodedimage, "camera");
-        if (attr)
-            if (! DXSetAttribute((Object)image, "camera", attr))
-            {
-                DXDelete((Object)image);
-                return NULL;
-            }
-        attr = DXGetAttribute(encodedimage, "object box");
-        if (attr)
-            if (! DXSetAttribute((Object)image, "object box", attr))
-            {
-                DXDelete((Object)image);
-                return NULL;
-            }
-        if (NULL != (attr = DXGetAttribute(encodedimage, IMAGE_TYPE)))
-            if (! DXSetComponentAttribute(image, IMAGE, IMAGE_TYPE, attr))
-            {
-                DXDelete((Object)image);
-                return NULL;
-            }
-        if (NULL != (attr = DXGetAttribute(encodedimage, X_SERVER)))
-            if (! DXSetAttribute((Object)image, X_SERVER, attr))
-            {
-                DXDelete((Object)image);
-                return NULL;
-            }
+ if (DXGetObjectClass(encodedimage) != CLASS_ARRAY)
+ {
+     DXSetError(ERROR_DATA_INVALID, "invalid encoded image");
+     return NULL;
+ }
+ if (DXGetObjectClass(attr) != CLASS_STRING)
+ {
+     DXSetError(ERROR_INTERNAL, "invalid encoded image");
+     return NULL;
+ }
+ str = DXGetString((String)attr);
+ DXMarkTime("decode start");
+ if (! strcmp(str, "8bit"))
+     image = decode_8bit((Array)encodedimage);
+ else if (! strcmp(str, "12bit"))
+     image = decode_12bit((Array)encodedimage);
+ else if (! strcmp(str, "24bit"))
+     image = decode_24bit((Array)encodedimage);
+ else if (! strcmp(str, "32bit"))
+     image = decode_32bit((Array)encodedimage);
+ else if (! strcmp(str, "RGBColor"))
+     image = decode_RGBColor((Array)encodedimage);
+ else
+ {
+     DXSetError(ERROR_INTERNAL, "invalid encoded image");
+     return NULL;
+ }
+ attr = DXGetAttribute(encodedimage, "image tag");
+ if (! attr)
+ {
+     DXSetError(ERROR_INTERNAL, "missing image tag");
+     DXDelete((Object)image);
+     return NULL;
+ }
+ if (! DXSetAttribute((Object)image, "image tag", attr))
+ {
+     DXDelete((Object)image);
+     return NULL;
+ }
+ attr = DXGetAttribute(encodedimage, "camera");
+ if (attr)
+     if (! DXSetAttribute((Object)image, "camera", attr))
+     {
+  DXDelete((Object)image);
+  return NULL;
+     }
+ attr = DXGetAttribute(encodedimage, "object box");
+ if (attr)
+     if (! DXSetAttribute((Object)image, "object box", attr))
+     {
+  DXDelete((Object)image);
+  return NULL;
+     }
+ if (NULL != (attr = DXGetAttribute(encodedimage, IMAGE_TYPE)))
+     if (! DXSetComponentAttribute(image, IMAGE, IMAGE_TYPE, attr))
+     {
+  DXDelete((Object)image);
+  return NULL;
+     }
+ if (NULL != (attr = DXGetAttribute(encodedimage, X_SERVER)))
+     if (! DXSetAttribute((Object)image, X_SERVER, attr))
+     {
+  DXDelete((Object)image);
+  return NULL;
+     }
     }
     DXMarkTime("decode end");
     return image;
