@@ -38,11 +38,15 @@ DXGetWindowsInstance(HINSTANCE *inst)
 {
 	if (! windowsInitialized)
 	{
-		DXSetError(ERROR_INTERNAL, "windows has not been initialized");
-		return ERROR;
+		if(!(appInstance = GetModuleHandle(NULL))) {
+			DXSetError(ERROR_INTERNAL, "windows has not been initialized");
+			return ERROR;
+		}
+		containerThreadID = GetCurrentThreadId();
 	}
 	*inst = appInstance;
 	return OK;
 }
 
-#endif /* DX_NATIVE_WINDOWS */
\ No newline at end of file
+#endif /* DX_NATIVE_WINDOWS */
+
