@@ -173,7 +173,8 @@ getSHMMAX()
     FILE *fd = fopen("/proc/sys/kernel/shmmax", "r");
     if (fd)
     {
-        fscanf(fd, "%lu", &shmmax);
+        if( fscanf(fd, "%lu", &shmmax) != 1)
+            shmmax = 0x2000000;
 	fclose(fd);
     }
     else
@@ -958,7 +959,9 @@ Pointer _dxfgetbrk(Pointer base, ulong n)
 	m = MEM_DATASEG;
 
     if (x == ERR_PTR) {
+#if !(defined(cygwin) || defined (macos))
 	unsigned int i;
+#endif
 	x = (Pointer)sbrk(0);
 #if defined(cygwin) || defined (macos)
 	DXSetError(ERROR_NO_MEMORY, 
@@ -1107,71 +1110,3 @@ void DXPrintMemoryInfo()
 }
 #endif  /* memory stats */
 
-#if !defined(intelnt) && !defined(WIN32)
-
-int DXForkChild(int i)
-{
-    int pid, master2slave[2], slave2master[2];
-
-    _dxf_lock_childpidtbl();
-
-    /*
-     * The slaves always need to hear from the master
-     */
-    if (pipe(master2slave))
-      return ERROR;
-
-    /*
-     * The master only needs to hear from slave[1]
-     */
-    if (i == 1)
-      if (pipe(slave2master))
-          return ERROR;
-
-    pid = fork();
-
-    /*
-     * The right thing to do depends on whether we're the parent 
-     * or child process.  The parent is always the master, and the
-     * child is always a slave.
-     */
-    if (pid)
-    {
-        /*
-         * The master writes to master2slave[1].
-         */
-        close(master2slave[0]);
-        _dxf_update_childpid(i, pid, master2slave[1]);
-
-        /*
-         * The master only needs to hear from slave[1]
-         */
-        if (i == 1)
-        {
-            close(slave2master[1]);
-            _dxf_set_RQ_ReadFromChild1(slave2master[0]);
-        }
-    }
-    else
-    {
-        /*
-         * The child is a slave.  It needs to listen to the
-         * master. Note that the slave2master pipe is only
-         * required for node 1, and that the master (if we
-	 * forked it at all) should not watch an master2slave
-         */
-        close(master2slave[1]);
-
-	if (i != 0)
-	    _dxf_set_RQ_reader(master2slave[0]);
-  
-        if (i == 1)
-        {
-              close(slave2master[0]);
-            _dxf_set_RQ_writer(slave2master[1]);
-        }
-    }
-
-    return  pid;
-}
-#endif
