@@ -22,30 +22,30 @@ shear(Pointer icstart, char cstc, RGBColor *cmap,
     float r, g, b, o, r0, g0, b0, o0, r1, g1, b1, o1, s0, s1, obar;
     float *iop, *oop;
     if (it) {
-        {int t=ikx; ikx=iky; iky=t;};
-        {int t=idx; idx=idy; idy=t;};
-        {int t=isx; isx=isy; isy=t;};
+ {int t=ikx; ikx=iky; iky=t;};
+ {int t=idx; idx=idy; idy=t;};
+ {int t=isx; isx=isy; isy=t;};
     }
     if (ot) {
-        {int t=onx; onx=ony; ony=t;};
-        ody = 1, odx = ony;
-        {float t=dzdx; dzdx=dzdy; dzdy=t;};
+ {int t=onx; onx=ony; ony=t;};
+ ody = 1, odx = ony;
+ {float t=dzdx; dzdx=dzdy; dzdy=t;};
     } else
-        odx = 1, ody = onx;
+ odx = 1, ody = onx;
     if (osx<0) {
-        osy-=skew*osx;
-        isx-=osx;
-        ikx+=osx;
-        osx=0;
+ osy-=skew*osx;
+ isx-=osx;
+ ikx+=osx;
+ osx=0;
     }
     if (onx-osx < ikx)
-        ikx = onx-osx;
+ ikx = onx-osx;
     oky = ony;
     if (cmap && omap) {
-        unsigned char *icp;
-        RGBColor *ocp;
-        {if (!(otype==type_colors && oostart && iostart)) DXErrorReturn(ERROR_ASSERTION, "assertion failure")};
-        
+ unsigned char *icp;
+ RGBColor *ocp;
+ {if (!(otype==type_colors && oostart && iostart)) DXErrorReturn(ERROR_ASSERTION, "assertion failure")};
+ 
  if (((scale)<0? -(scale) : (scale)) > 1.0) { 
  { 
  
@@ -221,11 +221,11 @@ shear(Pointer icstart, char cstc, RGBColor *cmap,
 }; 
  };
     } else if (cmap && !omap) {
-        unsigned char *icp;
-        RGBColor *ocp;
-        {if (!(otype==type_colors && oostart)) DXErrorReturn(ERROR_ASSERTION, "assertion failure")};
-        if (iostart) {
-            
+ unsigned char *icp;
+ RGBColor *ocp;
+ {if (!(otype==type_colors && oostart)) DXErrorReturn(ERROR_ASSERTION, "assertion failure")};
+ if (iostart) {
+     
  if (((scale)<0? -(scale) : (scale)) > 1.0) { 
  { 
  
@@ -400,8 +400,8 @@ shear(Pointer icstart, char cstc, RGBColor *cmap,
  } 
 }; 
  };
-        } else {
-            
+ } else {
+     
  if (((scale)<0? -(scale) : (scale)) > 1.0) { 
  { 
  
@@ -576,9 +576,9 @@ shear(Pointer icstart, char cstc, RGBColor *cmap,
  } 
 }; 
  };
-        }
+ }
     } else if (otype==type_colors) {
-        { 
+ { 
  RGBColor *icp; 
  RGBColor *ocp; 
  if (iostart && oostart) { 
@@ -1117,8 +1117,8 @@ shear(Pointer icstart, char cstc, RGBColor *cmap,
  } 
 };
     } else if (otype==type_fast) {
-        {if (!(!clip)) DXErrorReturn(ERROR_ASSERTION, "assertion failure")};
-        { 
+ {if (!(!clip)) DXErrorReturn(ERROR_ASSERTION, "assertion failure")};
+ { 
  RGBColor *icp; 
  struct fast *ocp; 
  if (iostart && oostart) { 
@@ -1657,8 +1657,8 @@ shear(Pointer icstart, char cstc, RGBColor *cmap,
  } 
 };
     } else if (otype==type_big) {
-        if (clip) {
-            { 
+ if (clip) {
+     { 
  RGBColor *icp; 
  struct big *ocp; 
  if (iostart && oostart) { 
@@ -2196,8 +2196,8 @@ shear(Pointer icstart, char cstc, RGBColor *cmap,
  
  } 
 };
-        } else {
-            { 
+ } else {
+     { 
  RGBColor *icp; 
  struct big *ocp; 
  if (iostart && oostart) { 
@@ -2735,7 +2735,7 @@ shear(Pointer icstart, char cstc, RGBColor *cmap,
  
  } 
 };
-        }
+ }
     }
     return OK;
 }
@@ -2754,8 +2754,8 @@ plane(Pointer ic,
 ) {
     float x, y, minx, miny, maxx, maxy, A, dzdx, dzdy;
     int isx, isy, ikx, iky;
-    float scale1, skew1, scale2, skew2, osy1, osy2, best, extra;
-    int ti1, to1, ti2, to2, contrary=0, osx2;
+    float scale1=0, skew1=0, scale2=0, skew2=0, osy1, osy2, best, extra;
+    int ti1=0, to1, ti2, to2=0, contrary=0, osx2;
     int nx1, ny1, nk, nc;
     RGBColor *ic1=NULL;
     float *io1=NULL;
@@ -2767,7 +2767,7 @@ plane(Pointer ic,
     if (((vx)<0? -(vx) : (vx))>best) ti1=0, scale1=vx, skew1=ux, scale2=-A/vx, skew2=vy/vx, to2=0, best=((vx)<0? -(vx) : (vx));
     if (((vy)<0? -(vy) : (vy))>best) ti1=0, scale1=vy, skew1=uy, scale2=A/vy, skew2=vx/vy, to2=1, best=((vy)<0? -(vy) : (vy));
     if (scale1==0 || scale2==0)
-        return OK;
+ return OK;
     dzdx = (vy*uz - uy*vz) / A;
     dzdy = (ux*vz - vx*uz) / A;
     osz -= osx*dzdx + osy*dzdy;
@@ -2809,26 +2809,26 @@ plane(Pointer ic,
     ic1 = (RGBColor *) DXAllocateLocalZero(nx1 * ny1 * sizeof(*ic1));
     io1 = (float *) DXAllocateLocalZero(nx1 * ny1 * sizeof(*io1));
     if (!ic1 || !io1)
-        return ERROR;
+ return ERROR;
     DXMarkTimeLocal("overhead");
     rc = shear(ic, cstc, cmap,
-          io, csto, omap,
-          1.0,1.0,
-          idx,idy,isx,isy,ikx,iky,
-          0,0,0,0,
-          (Pointer)ic1,type_colors,io1,
-          0,osy1,nx1,ny1,
-          ti1,scale1,skew1,to1);
+   io, csto, omap,
+   1.0,1.0,
+   idx,idy,isx,isy,ikx,iky,
+   0,0,0,0,
+   (Pointer)ic1,type_colors,io1,
+   0,osy1,nx1,ny1,
+   ti1,scale1,skew1,to1);
     if (!rc) goto error;
     DXMarkTimeLocal("shear 1");
     rc = shear((Pointer)ic1, 0, NULL,
-          (Pointer)io1, 0, NULL,
-          cmul,omul,
-          1,nx1,0,0,nx1,ny1,
-          osz,dzdx,dzdy,clip,
-          oc,otype,NULL,
-          osx2,osy2,onx,ony,
-          ti2,scale2,skew2,to2);
+   (Pointer)io1, 0, NULL,
+   cmul,omul,
+   1,nx1,0,0,nx1,ny1,
+   osz,dzdx,dzdy,clip,
+   oc,otype,NULL,
+   osx2,osy2,onx,ony,
+   ti2,scale2,skew2,to2);
     if (!rc) goto error;
     DXMarkTimeLocal("shear 2");
     DXFree((Pointer)ic1);
@@ -2841,17 +2841,17 @@ error:
 }
 Error
 _dxf_CompositePlane(struct buffer *b, float osx, float osy, float osz,
-                    int clip,
-                    float ux, float uy, float uz, float vx, float vy, float vz,
-                    Pointer ic, char cstc, RGBColor *cmap,
-                    Pointer io, char csto, float *omap,
-                    float cmul, float omul,
-                    int idx, int idy, int inx, int iny
+      int clip,
+      float ux, float uy, float uz, float vx, float vy, float vz,
+      Pointer ic, char cstc, RGBColor *cmap,
+      Pointer io, char csto, float *omap,
+      float cmul, float omul,
+      int idx, int idy, int inx, int iny
 ) {
     return plane(ic, cstc, cmap, io, csto, omap, cmul, omul,
-                 idx, idy, inx, iny,
-                 ux, uy, uz, vx, vy, vz,
-                 (Pointer)b->u.big,
-                 b->pix_type==pix_fast? type_fast : type_big,
-                 b->width, b->height, osx, osy, osz, clip);
+   idx, idy, inx, iny,
+   ux, uy, uz, vx, vy, vz,
+   (Pointer)b->u.big,
+   b->pix_type==pix_fast? type_fast : type_big,
+   b->width, b->height, osx, osy, osz, clip);
 }
