@@ -269,7 +269,7 @@ DXRender(Object o, Camera camera, char *format)
     struct common c, *cp;
     int ci, irregular, n, i, j;
     int nosplit;
-    int x, y, left, bot, lt, rt, tp, bt, split;
+    int x, y, left, bot, lt, rt=0, tp=0, bt, split;
     Point box[8];
     float width;
     int	depth;
@@ -349,7 +349,15 @@ DXRender(Object o, Camera camera, char *format)
 				      format);
 	    c.img_type = img_x;
 	    DXDebug("R", "X format");
-	} else {
+	} else if(format[0]=='W') { 
+		// Make c.image as compatible with a Windows DIB bitmap as possible.
+		c.image = _dxf_MakeImage(c.width, 
+			c.height, 
+			24,
+			format);
+		c.img_type = img_rgb;
+	}
+	else {
 	    c.image = DXMakeImageFormat(c.width, c.height, format);
 	    c.img_type = img_rgb;
 	}
