@@ -223,7 +223,7 @@ DXWaitTime(double seconds)
     while (DXGetTime() - old < seconds)
 	continue;
 
-#elif ibm6000 || sun4
+#elif ibm6000 || sun4 || macos || linux || freebsd || cygwin
 
     usleep((int)(1000000.0 * seconds));
 
@@ -294,9 +294,9 @@ void DXMarkTimeLocalX (char *s) {               mark(s, 0);}
 void
 DXPrintTimes(void)
 {
-    int i, id;
+    int i, id=0;
     static struct last glob;
-    struct _proc *proc, *p;
+    struct _proc *proc = NULL, *p;
     struct event *event;
     struct last *last;
     DXBeginLongMessage();
