@@ -19,6 +19,7 @@
 #include "ControlPanel.h"
 #include "Cacheability.h"
 #include "InsertNetworkDialog.h"
+#include "Stack.h"
 
 typedef long NodeStatusChange;
 
@@ -55,6 +56,7 @@ class ControlPanel;
 class NodeDefinition;
 class ToolSelector;
 class EditorWorkSpace;
+class WorkSpaceComponent;
 class VPERoot;
 class Ark;
 class Node;
@@ -79,6 +81,10 @@ class Decorator;
 class DecoratorStyle;
 class GetSetConversionDialog;
 class TransmitterNode;
+class GraphLayout;
+class VPEAnnotator;
+class XHandler;
+class UndoableAction;
 
 #if WORKSPACE_PAGES
 class GroupManager;
@@ -97,6 +103,8 @@ class EditorWindow : public DXWindow
   friend class DXApplication;	// For the constructor 
   friend class NoUndoEditorCommand; 
   friend class DeleteNodeCommand; 
+  friend class UndoDeletion; // for createNetFileFromSelection
+  friend class PageSelector; // for setCommandActivation() in PageSelector::selectPage()
   friend ControlPanel::~ControlPanel();
 
   private:
@@ -117,6 +125,7 @@ class EditorWindow : public DXWindow
     friend void EditorWindow_SelectionDoneCB(Widget, Atom *, Atom *);
     friend void EditorWindow_SelectionReadyCB (Widget , XtPointer , Atom *,
 	Atom *, XtPointer , unsigned long *, int *);
+    static boolean KeyHandler(XEvent *event, void *clientData);
 
     static void SetOwner(void*);
     static void DeleteSelections(void*);
@@ -159,8 +168,10 @@ class EditorWindow : public DXWindow
 
     //
     // Origin of the workspace window, used for error node finding
+    // and for 'restore' in the find tool dialog.
     //
     int    Ox, Oy;
+    char*  find_restore_page;
 
     void   openSelectedINodes();
 
@@ -192,14 +203,14 @@ class EditorWindow : public DXWindow
     // Convert nets to use GetLocal/Global and SetLocal/Global
     // instead of Get and Set (nodes).
     //
-           void EditorWindow::postGetSetConversionDialog();
-    static void EditorWindow::ConvertToLocal();
-    static void EditorWindow::ConvertToGlobal(boolean global = TRUE);
+           void postGetSetConversionDialog();
+    static void ConvertToLocal();
+    static void ConvertToGlobal(boolean global = TRUE);
 
     void convertToGlobal(boolean global);
 
-    static Command*  EditorWindow::SelectedToGlobalCmd;
-    static Command*  EditorWindow::SelectedToLocalCmd;
+    static Command*  SelectedToGlobalCmd;
+    static Command*  SelectedToLocalCmd;
 
     CascadeMenu		*programVerifyCascade;	
 
@@ -207,7 +218,7 @@ class EditorWindow : public DXWindow
     Command		*toLocalCmd;
     Command		*postGetSetCmd;
 
-    static GetSetConversionDialog* EditorWindow::GetSetDialog;
+    static GetSetConversionDialog* GetSetDialog;
 #endif
 
     //
@@ -242,6 +253,21 @@ class EditorWindow : public DXWindow
     void resetErrorList(boolean reset_all=TRUE);
     void resetColorList() { this->resetExecutionList(); this->resetErrorList(); }
 
+    //
+    // Automatic graph layout
+    //
+    GraphLayout* layout_controller;
+
+    //
+    // Record moved StandIns and decorators so that movement
+    // can be undone. ...on behalf of the new graph layout operation.
+    //
+    Stack undo_list;
+    boolean moving_many_standins;
+    boolean performing_undo;
+    boolean creating_new_network;
+    void clearUndoList();
+
   protected:
     //
     // State information:
@@ -300,6 +326,7 @@ class EditorWindow : public DXWindow
 #endif
     Command*		javifyNetCmd;
     Command*		unjavifyNetCmd;
+    Command*		reflowGraphCmd;
     Command*            gridCmd;
     Command*		setPanelGroupCmd;
     Command*		setPanelAccessCmd;
@@ -365,6 +392,8 @@ class EditorWindow : public DXWindow
     CommandInterface*	valuesOption;
     CommandInterface*	findToolOption;
     CascadeMenu		*editTabsCascade;	
+    CommandInterface*	addInputTabOption;
+    CommandInterface*	removeInputTabOption;
     CascadeMenu		*editSelectCascade;	
     CascadeMenu		*outputCacheabilityCascade;	
     CascadeMenu		*editOutputCacheabilityCascade;	
@@ -377,6 +406,8 @@ class EditorWindow : public DXWindow
     CommandInterface*	copyOption;
     CommandInterface*	pasteOption;
     CommandInterface*	macroNameOption;
+    CommandInterface*	reflowGraphOption;
+    CommandInterface*	undoOption;
     CommandInterface*	insertNetworkOption;
     CommandInterface*	addAnnotationOption;
     CommandInterface*	createMacroOption;
@@ -488,6 +519,9 @@ class EditorWindow : public DXWindow
     boolean	cutSelectedNodes();
     boolean	copySelectedNodes(boolean delete_property = FALSE);
     boolean	pasteCopiedNodes();
+    char*       createNetFileFromSelection(int& net_len, char** cfg_out, int& cfg_len);
+    boolean     setPendingPaste (const char* net_file_name,
+	    const char* cfg_file_name, boolean ignoreUndefinedModules=FALSE);
 
     //
     // When the user clicks the Edit/Add Decorator option, we create a new
@@ -544,6 +578,17 @@ class EditorWindow : public DXWindow
     //
     boolean placeDecorator();
 
+    //
+    // In addition to setting command activation based on undo_list size,
+    // also set the text of the undo button label.
+    //
+    void setUndoActivation();
+
+    // work around for a motif bug - hitting pg up,down in the vpe crashes dxui
+    XHandler* pgKeyHandler;
+
+    boolean keyHandler(XEvent* event);
+
   public:
 
     //
@@ -603,6 +648,7 @@ class EditorWindow : public DXWindow
     void highlightNode(const char* name, int instance, int flag);
     boolean selectNode(Node *node, boolean select, boolean moveto = TRUE);
     boolean selectNode(char* name, int instance, boolean select);
+    boolean selectDecorator (VPEAnnotator* dec, boolean select, boolean moveto=TRUE);
     void selectUnselectedNodes();
     void deselectAllNodes(); 
     void selectAllNodes();
@@ -660,14 +706,20 @@ class EditorWindow : public DXWindow
 
     //
     // add the node selected in the toolList to the vpe at x,y
+    // Added stitch 11/8/02.  When it's set to TRUE, we're going to handle
+    // conflicts of node type/inst # by replacing the copy in the merging
+    // network with the copy in the real network.  This is useful in 
+    // implemented Undo of Cut/Delete.  For this we need to copy not only
+    // selected nodes, but also nodes they're wired to so that we can
+    // restore the wires that were broken as a result of the cut.
     //
-    void addCurrentNode(int x, int y, EditorWorkSpace *where);
+    void addCurrentNode(int x, int y, EditorWorkSpace *where, boolean stitch=FALSE);
     void addNode (NodeDefinition *, int x, int y, EditorWorkSpace *where);
 
     //
     // Move the workspace window if the selected error node is not shown 
     //
-    void moveWorkspaceWindow(StandIn*);
+    void moveWorkspaceWindow(UIComponent*);
 
     //
     // Move the workSpace inside the scrolled window so that the given x,y
@@ -721,10 +773,9 @@ class EditorWindow : public DXWindow
     void newDecorator(Decorator* dec, EditorWorkSpace* where=NUL(EditorWorkSpace*));
 
     //
-    // notify the a standIn that an arc has been added to the 
-    // node
+    // notify the a standIn that an arc has been added/deleted to/from the node
     //
-    void notifyArk(Ark *a);
+    void notifyArk(Ark *a, boolean added=TRUE);
 
     FindToolDialog* getFindDialog()
     {
@@ -737,9 +788,9 @@ class EditorWindow : public DXWindow
 
     Command *getDeleteNodeCmd(){return this->deleteNodeCmd;};
 #ifndef FORGET_GETSET
-    static Command* EditorWindow::GetGlobalCmd() 
+    static Command* GetGlobalCmd() 
 	{ return EditorWindow::SelectedToGlobalCmd; };
-    static Command* EditorWindow::GetLocalCmd() 
+    static Command* GetLocalCmd() 
 	{ return EditorWindow::SelectedToLocalCmd; };
 #endif
 
@@ -879,7 +930,7 @@ class EditorWindow : public DXWindow
     // On behalf of VPEAnnotators which have the ability to snarf whole nets and
     // set them back into the selection via XtOwnSelection...
     //
-    void EditorWindow::setCopiedNet(const char*);
+    void setCopiedNet(const char*);
 #endif
 
     //
@@ -894,6 +945,44 @@ class EditorWindow : public DXWindow
     boolean javifyNetwork();
     boolean unjavifyNetwork();
 
+    //
+    // Use GraphLayout to modify the flow of the graph.
+    //
+    boolean reflowEntireGraph();
+
+    //
+    // register undo information
+    //
+    void  saveLocationForUndo (UIComponent* uic, boolean mouse=FALSE, boolean same_event=FALSE);
+    void  saveAllLocationsForUndo (UndoableAction* gridding);
+    void  beginMultipleCanvasMovements();
+    void  endMultipleCanvasMovements() { this->moving_many_standins = FALSE; }
+
+    //
+    // a mechanism for Node to notify us that his definition has changed.  We
+    // throw out the undo list because this will probably involve changes that
+    // we can't work around i.e. types of io tabs will be different and attempts
+    // to reconnect tabs will fail.
+    //
+    void notifyDefinitionChange(Node* n) { this->clearUndoList(); }
+
+    //
+    // perform undo operation
+    //
+    boolean undo();
+
+    //
+    // Receive a notification that the net has been saved and marked clean
+    //
+    void notifySaved() { this->clearUndoList(); }
+
+    //
+    // FindToolDialog requires support in order to move the canvas back
+    // the original location before the first find operation.  This used
+    // to happen via a side effect in moveWorkspaceWindow() which was
+    // broken with the addition of vpe pages.
+    //
+    void checkPointForFindDialog(FindToolDialog*);
 
     //
     // Returns a pointer to the class name.
