@@ -1,17 +1,14 @@
-/****************************************************************************/
-/*                         I.B.M. CONFIDENTIAL                              */
-/*       xxxx-yyy (c) COPYRIGHT IBM CORP. 1993   ALL RIGHTS RESERVED.       */
-/*                                                                          */
-/*     (I.B.M. CONFIDENTIAL-RESTRICTED when combined with the aggregated    */
-/*                  OCO source materials for this program.)                 */
-/*                         OCO SOURCE MATERIAL                              */
-/*                    LICENSED MATERIALS-PROPERTY OF IBM.                   */
-/*                                                                          */
-/****************************************************************************/
+/***********************************************************************/
+/* Open Visualization Data Explorer                                    */
+/* (C) Copyright IBM Corp. 1989,1999                                   */
+/* ALL RIGHTS RESERVED                                                 */
+/* This code licensed under the                                        */
+/*    "IBM PUBLIC LICENSE - Open Visualization Data Explorer"          */
+/***********************************************************************/
 
 
 /*
- * $Header: /src/master/dx/src/uipp/java/server/DXLink.c,v 1.8 2003/07/11 05:50:55 davidt Exp $
+ * $Header: /src/master/dx/src/uipp/java/server/DXLink.c,v 1.11 2006/07/21 17:56:29 davidt Exp $
  */
 #if defined(hp700) 
 #define _UINT64_T
@@ -105,21 +102,40 @@ JNIEXPORT jlong JNICALL Java_server_DXServer_DXLStartDX
 {
 char cmdstr[256];
 DXLConnection* dxl;
+	jclass newExcCls;
+        const char *host;
+        const char *cmd;
+        const char *dxargs;
+	
+	(*env)->ExceptionDescribe(env);
+	(*env)->ExceptionClear(env);
+	newExcCls = (*env)->FindClass(env, "java/lang/IllegalArgumentException");
 
-    const char *host = (*env)->GetStringUTFChars(env, jhost,0);
-    const char *cmd = (*env)->GetStringUTFChars(env, jcmdstr,0);
-    const char* dxargs = (const char*)getenv("DXARGS");
+    host = (*env)->GetStringUTFChars(env, jhost,0);
+    cmd = (*env)->GetStringUTFChars(env, jcmdstr,0);
+    dxargs = (const char*)getenv("DXARGS");
 
     if ((dxargs) && (dxargs[0]))
 	sprintf (cmdstr, "dx %s", dxargs);
     else
 	strcpy (cmdstr, cmd);
     dxl = DXLStartDX(cmdstr, host);
+        
     /* if (dxl) DXLSetMessageDebugging(dxl, 1); */
 
     (*env)->ReleaseStringUTFChars(env, jcmdstr, cmd);
     (*env)->ReleaseStringUTFChars(env, jhost, host);
 
+    /* Should now look at dxl and the errno to see what happened. */
+    /* If it returns null, then throw a java exception. */
+    if(dxl == NULL) {
+    	if(newExcCls == NULL)
+    		return 0;
+    	else
+    		(*env)->ThrowNew(env, newExcCls, "err starting dx server--check dxserver.hosts file.");
+    }
+
+
     return (long)dxl;
 }
 
