@@ -344,7 +344,7 @@ static int RemoveControlPoint( ControlMap* map, int index )
     int i;
 
     if( (index < 0) || (index >= map->num_points) )
-	return;
+	return 0;
     /*  Move everything between there and index down  */
     for( i=index+1; i<map->num_points; i++ )
     {
@@ -354,6 +354,7 @@ static int RemoveControlPoint( ControlMap* map, int index )
 			sizeof(XRectangle));
     }
     --map->num_points;
+    return 0;
 }
 
 
@@ -385,10 +386,9 @@ static int MoveControlPoint( ControlMap* map, int index, int x, int y )
 static int RepositionControlPoint( ControlMap* map, int index,
 				   double level, double value )
 {
-int i, j;
 Boolean get_new_vals;
 Boolean use_adjacent_level;
-double adjacent_level;
+double adjacent_level=0;
 int min_y, max_y;
 
     /*
@@ -483,7 +483,6 @@ static int GetControlPoint( ControlMap* map, int x, int y, int grab_mode )
     int save_error;
     int save_i;
     register int error_i, error_y;
-    register int error_j;
 
     GetControlValues(map, x, y, &level, &value);
     /*  Position i at the index we want to use  */
@@ -559,8 +558,6 @@ void DrawControlBoxes( ControlMap* map, GC gc )
 {
     int start, finish, index;
     int low, high;
-    char buf[4];
-    int i;
 
     if (gc == NULL) return;
 
@@ -656,33 +653,29 @@ Boolean MapInput( Widget w, ControlMap* map,
 		  XmDrawingAreaCallbackStruct* call_data )
 {
 ControlField    *field;
-double level, value;
 static Time time = 0;	/* Time of last button1 press event */
 int index, dummy_index;
 int delta_y, delta_x;
-int old_x;
+int old_x=0;
 int xmax;
 int xmin;
 int point;
 Boolean constrain_horizontal;
 Boolean constrain_vertical;
 int i;
-int j;
 Boolean set;
-Boolean changed;
-
 
     if ( ((call_data->event->type == ButtonPress) || 
 	  (call_data->event->type == ButtonRelease)) &&
          (call_data->event->xbutton.button != Button1) )
 	{
-	return;
+	return FALSE;
 	}
 
     if ( (call_data->event->type == MotionNotify) &&
 	!(call_data->event->xmotion.state & Button1Mask) )
 	{
-	return;
+	return FALSE;
 	}
     constrain_vertical = map->field->cmew->color_map_editor.constrain_vert &&
 			 map->toggle_on;
@@ -714,7 +707,6 @@ Boolean changed;
 			    XtVaSetValues( field->toggle_b,
 				XmNset, False, NULL);
 			    field->map[0]->toggle_on = False;
-			    changed = False;
 			    }
 			}
 		    }
@@ -818,7 +810,7 @@ Boolean changed;
 	/*
 	 * Shift/Button events are processed in the button press.
 	 */
-	if(ShiftMask & call_data->event->xmotion.state) return;
+	if(ShiftMask & call_data->event->xmotion.state) return FALSE;
 
 	if( map->grabbed >= 0 )
 	    {
@@ -989,7 +981,7 @@ Boolean changed;
 	if(ShiftMask & call_data->event->xbutton.state)
 	    {
 	    CallActivateCallback(map->field->cmew, XmCR_SELECT);
-	    return;
+	    return FALSE;
 	    }
 
 	if (map->rubber_banding)
@@ -1078,7 +1070,6 @@ static void DrawMultiPointGrabBoxes( Widget w, ControlMap* map)
 {
 int start, finish;
 int low, high;
-char buf[4];
 int yupper, ylower, index;
 
     if( map->field->vertical )
@@ -1178,25 +1169,10 @@ int index;
 void CallActivateCallback( XmColorMapEditorWidget cmew, int reason)
 {
 XmColorMapEditorCallbackStruct call_value;
-int 		i, j;
+int 		i;
 ControlField 	*field;
 ControlMap 	*map;
 int		index;
-double		range, minimum, level;
-double		value;
-struct 
-    {
-    Boolean	occupied;
-    int		num_hues;
-    int		num_sats;
-    int		num_vals;
-    int		hue_index[2];
-    int		sat_index[2];
-    int		val_index[2];
-    int		wrap_around;
-    double	level;
-    } flags[NUM_LEVELS];
-int		num_alloced_pts;
 
     call_value.reason = reason;
     call_value.op_values = NULL;
@@ -1306,6 +1282,22 @@ int		num_alloced_pts;
 	    }
 	}
 #ifdef Comment
+{
+    struct 
+    {
+    Boolean	occupied;
+    int		num_hues;
+    int		num_sats;
+    int		num_vals;
+    int		hue_index[2];
+    int		sat_index[2];
+    int		val_index[2];
+    int		wrap_around;
+    double	level;
+    } flags[NUM_LEVELS];
+
+    int		num_alloced_pts;
+
     /* Initialize the flags array */
     for (i = 0; i < NUM_LEVELS; i++)
 	{
@@ -1552,10 +1544,11 @@ int		num_alloced_pts;
 		 field->map[0]->line[0].values[(int)(NUM_LEVELS-1)];
 	    }
 	call_value.num_op_points = num_alloced_pts;
+ }
 #endif
-	minimum = cmew->color_map_editor.value_minimum;
-	range = (cmew->color_map_editor.value_maximum -
-                 cmew->color_map_editor.value_minimum);
+	/*minimum = cmew->color_map_editor.value_minimum;*/
+	/*range = (cmew->color_map_editor.value_maximum -*/
+        /*	   cmew->color_map_editor.value_minimum);*/
 
 	/* Hue field */
 	map = cmew->color_map_editor.g.field[HUE]->map[0];
@@ -2067,17 +2060,17 @@ void XmColorMapEditorLoad(Widget cmew, double min, double max,
 			  int nvals, double *vals,
 			  int nopat, double *opat)
 {
-int i,j;
-char *message;
-Arg wargs[12];
-double norm, range;
+int i;
+double norm, range=0;
 Boolean skip_normalize;
-XtArgVal	dx_l;
+#ifdef PASSDOUBLEVALUE
+XtArgVal dx_l;
+#endif
 
     XmColorMapEditorWidget w = (XmColorMapEditorWidget)cmew;
 
     /* Erase the old Control points */
-    if (XtIsRealized(w))
+    if (XtIsRealized((Widget)w))
     {
 	for (i=0; i<4; i++)
 	{
@@ -2109,7 +2102,7 @@ XtArgVal	dx_l;
 		XmNdValue, DoubleVal(max, dx_l), NULL);
     }
 
-    if(XtIsRealized(w))
+    if(XtIsRealized((Widget)w))
 	for(i = 0; i < 4; i++)
 	    RemoveAllControlPoints(w->color_map_editor.g.field[i]);
 
@@ -2161,7 +2154,7 @@ XtArgVal	dx_l;
 			True );
     }
 
-    if(XtIsRealized(w))
+    if(XtIsRealized((Widget)w))
     {
 	for(i = 0; i < 4; i++)
 	{
@@ -2198,8 +2191,7 @@ int i, j;
 void CMESawToothWave(Widget w, int nsteps, Boolean start_on_left,
 		     Boolean use_selected)
 {
-int 			i,j;
-ControlPoint 		cp_ptr;
+int 			i;
 double 			level;
 double 			value;
 double 			tmp_value;
@@ -2209,8 +2201,8 @@ ControlMap 		*map;
 double 			real_min_level;
 double 			real_max_level;
 int			num_selected;
-int			pt_index1;
-int			pt_index2;
+int			pt_index1=0;
+int			pt_index2=0;
 int			field;
 double			min_value;
 double			max_value;
@@ -2331,24 +2323,23 @@ double			max_level;
 void CMESquareWave(Widget w, int nsteps, Boolean start_on_left,
 		   Boolean use_selected)
 {
-ControlPoint cp_ptr;
-int 			i, n;
+int 			i;
 double 			level;
 double 			value;
 double 			tmp_value;
 double 			level_inc;
 XmColorMapEditorWidget	cmew = (XmColorMapEditorWidget)w;
-ControlMap 		*map;
-double 			real_min_level;
-double 			real_max_level;
+ControlMap 		*map=NULL;
+double 			real_min_level=0;
+double 			real_max_level=0;
 int			num_selected;
-int			pt_index1;
-int			pt_index2;
+int			pt_index1=0;
+int			pt_index2=0;
 int			field;
-double			min_value;
-double			max_value;
-double			min_level;
-double			max_level;
+double			min_value=0;
+double			max_value=0;
+double			min_level=0;
+double			max_level=0;
 
     PushUndoPoints(cmew);
     for(field = 0; field < 4; field++)
@@ -2466,9 +2457,7 @@ double			max_level;
 
 void CMEStep(Widget w, int nsteps, Boolean use_selected)
 {
-int 			i,j;
-ControlPoint 		cp_ptr;
-int 			num_points, n;
+int 			i;
 double 			level;
 double 			value;
 double 			inc_level;
@@ -2480,8 +2469,8 @@ double 			real_max_level;
 double 			real_min_value;
 double 			real_max_value;
 int			num_selected;
-int			pt_index1;
-int			pt_index2;
+int			pt_index1=0;
+int			pt_index2=0;
 int			field;
 double			min_value;
 double			max_value;
